/**
  ******************************************************************************
  * @file    stm32l4r9i_eval_gfxmmu_lut.h
  * @author  MCD Application Team
  * @version $VERSION$
  * @date    $DATE$
  * @brief   This file contains GFXMMU look-up-table for DSI round LCD.
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT(c) 2016 STMicroelectronics</center></h2>
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
  *   1. Redistributions of source code must retain the above copyright notice,
  *      this list of conditions and the following disclaimer.
  *   2. Redistributions in binary form must reproduce the above copyright notice,
  *      this list of conditions and the following disclaimer in the documentation
  *      and/or other materials provided with the distribution.
  *   3. Neither the name of STMicroelectronics nor the names of its contributors
  *      may be used to endorse or promote products derived from this software
  *      without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __STM32L4R9I_EVAL_GFXMMU_LUT_H
#define __STM32L4R9I_EVAL_GFXMMU_LUT_H

#ifdef __cplusplus
 extern "C" {
#endif

#define GFXMMU_LCD_SIZE 390
#define GFXMMU_LUT_SIZE (2 * GFXMMU_LCD_SIZE)

#if ( EW_FRAME_BUFFER_COLOR_FORMAT == EW_FRAME_BUFFER_COLOR_FORMAT_RGB565 )
static const uint32_t gfxmmu_lut_config[GFXMMU_LUT_SIZE] = {
    0x001a1601, // GFXMMU_LUT0L
    0x003ffea0, // GFXMMU_LUT0H
    0x001b1501, // GFXMMU_LUT1L
    0x003fff00, // GFXMMU_LUT1H
    0x001c1401, // GFXMMU_LUT2L
    0x003fff80, // GFXMMU_LUT2H
    0x001c1301, // GFXMMU_LUT3L
    0x00000020, // GFXMMU_LUT3H
    0x001d1301, // GFXMMU_LUT4L
    0x000000c0, // GFXMMU_LUT4H
    0x001e1201, // GFXMMU_LUT5L
    0x00000180, // GFXMMU_LUT5H
    0x001e1201, // GFXMMU_LUT6L
    0x00000250, // GFXMMU_LUT6H
    0x001e1101, // GFXMMU_LUT7L
    0x00000330, // GFXMMU_LUT7H
    0x001f1101, // GFXMMU_LUT8L
    0x00000410, // GFXMMU_LUT8H
    0x001f1001, // GFXMMU_LUT9L
    0x00000510, // GFXMMU_LUT9H
    0x00201001, // GFXMMU_LUT10L
    0x00000610, // GFXMMU_LUT10H
    0x00201001, // GFXMMU_LUT11L
    0x00000720, // GFXMMU_LUT11H
    0x00200f01, // GFXMMU_LUT12L
    0x00000840, // GFXMMU_LUT12H
    0x00210f01, // GFXMMU_LUT13L
    0x00000960, // GFXMMU_LUT13H
    0x00210f01, // GFXMMU_LUT14L
    0x00000a90, // GFXMMU_LUT14H
    0x00210e01, // GFXMMU_LUT15L
    0x00000bd0, // GFXMMU_LUT15H
    0x00220e01, // GFXMMU_LUT16L
    0x00000d10, // GFXMMU_LUT16H
    0x00220e01, // GFXMMU_LUT17L
    0x00000e60, // GFXMMU_LUT17H
    0x00220e01, // GFXMMU_LUT18L
    0x00000fb0, // GFXMMU_LUT18H
    0x00220d01, // GFXMMU_LUT19L
    0x00001110, // GFXMMU_LUT19H
    0x00230d01, // GFXMMU_LUT20L
    0x00001270, // GFXMMU_LUT20H
    0x00230d01, // GFXMMU_LUT21L
    0x000013e0, // GFXMMU_LUT21H
    0x00230d01, // GFXMMU_LUT22L
    0x00001550, // GFXMMU_LUT22H
    0x00230c01, // GFXMMU_LUT23L
    0x000016d0, // GFXMMU_LUT23H
    0x00240c01, // GFXMMU_LUT24L
    0x00001850, // GFXMMU_LUT24H
    0x00240c01, // GFXMMU_LUT25L
    0x000019e0, // GFXMMU_LUT25H
    0x00240c01, // GFXMMU_LUT26L
    0x00001b70, // GFXMMU_LUT26H
    0x00240b01, // GFXMMU_LUT27L
    0x00001d10, // GFXMMU_LUT27H
    0x00240b01, // GFXMMU_LUT28L
    0x00001eb0, // GFXMMU_LUT28H
    0x00250b01, // GFXMMU_LUT29L
    0x00002050, // GFXMMU_LUT29H
    0x00250b01, // GFXMMU_LUT30L
    0x00002200, // GFXMMU_LUT30H
    0x00250b01, // GFXMMU_LUT31L
    0x000023b0, // GFXMMU_LUT31H
    0x00250a01, // GFXMMU_LUT32L
    0x00002570, // GFXMMU_LUT32H
    0x00250a01, // GFXMMU_LUT33L
    0x00002730, // GFXMMU_LUT33H
    0x00260a01, // GFXMMU_LUT34L
    0x000028f0, // GFXMMU_LUT34H
    0x00260a01, // GFXMMU_LUT35L
    0x00002ac0, // GFXMMU_LUT35H
    0x00260a01, // GFXMMU_LUT36L
    0x00002c90, // GFXMMU_LUT36H
    0x00260a01, // GFXMMU_LUT37L
    0x00002e60, // GFXMMU_LUT37H
    0x00260901, // GFXMMU_LUT38L
    0x00003040, // GFXMMU_LUT38H
    0x00270901, // GFXMMU_LUT39L
    0x00003220, // GFXMMU_LUT39H
    0x00270901, // GFXMMU_LUT40L
    0x00003410, // GFXMMU_LUT40H
    0x00270901, // GFXMMU_LUT41L
    0x00003600, // GFXMMU_LUT41H
    0x00270901, // GFXMMU_LUT42L
    0x000037f0, // GFXMMU_LUT42H
    0x00270901, // GFXMMU_LUT43L
    0x000039e0, // GFXMMU_LUT43H
    0x00270801, // GFXMMU_LUT44L
    0x00003be0, // GFXMMU_LUT44H
    0x00270801, // GFXMMU_LUT45L
    0x00003de0, // GFXMMU_LUT45H
    0x00280801, // GFXMMU_LUT46L
    0x00003fe0, // GFXMMU_LUT46H
    0x00280801, // GFXMMU_LUT47L
    0x000041f0, // GFXMMU_LUT47H
    0x00280801, // GFXMMU_LUT48L
    0x00004400, // GFXMMU_LUT48H
    0x00280801, // GFXMMU_LUT49L
    0x00004610, // GFXMMU_LUT49H
    0x00280801, // GFXMMU_LUT50L
    0x00004820, // GFXMMU_LUT50H
    0x00280701, // GFXMMU_LUT51L
    0x00004a40, // GFXMMU_LUT51H
    0x00280701, // GFXMMU_LUT52L
    0x00004c60, // GFXMMU_LUT52H
    0x00290701, // GFXMMU_LUT53L
    0x00004e80, // GFXMMU_LUT53H
    0x00290701, // GFXMMU_LUT54L
    0x000050b0, // GFXMMU_LUT54H
    0x00290701, // GFXMMU_LUT55L
    0x000052e0, // GFXMMU_LUT55H
    0x00290701, // GFXMMU_LUT56L
    0x00005510, // GFXMMU_LUT56H
    0x00290701, // GFXMMU_LUT57L
    0x00005740, // GFXMMU_LUT57H
    0x00290701, // GFXMMU_LUT58L
    0x00005970, // GFXMMU_LUT58H
    0x00290601, // GFXMMU_LUT59L
    0x00005bb0, // GFXMMU_LUT59H
    0x00290601, // GFXMMU_LUT60L
    0x00005df0, // GFXMMU_LUT60H
    0x002a0601, // GFXMMU_LUT61L
    0x00006030, // GFXMMU_LUT61H
    0x002a0601, // GFXMMU_LUT62L
    0x00006280, // GFXMMU_LUT62H
    0x002a0601, // GFXMMU_LUT63L
    0x000064d0, // GFXMMU_LUT63H
    0x002a0601, // GFXMMU_LUT64L
    0x00006720, // GFXMMU_LUT64H
    0x002a0601, // GFXMMU_LUT65L
    0x00006970, // GFXMMU_LUT65H
    0x002a0601, // GFXMMU_LUT66L
    0x00006bc0, // GFXMMU_LUT66H
    0x002a0601, // GFXMMU_LUT67L
    0x00006e10, // GFXMMU_LUT67H
    0x002a0501, // GFXMMU_LUT68L
    0x00007070, // GFXMMU_LUT68H
    0x002a0501, // GFXMMU_LUT69L
    0x000072d0, // GFXMMU_LUT69H
    0x002b0501, // GFXMMU_LUT70L
    0x00007530, // GFXMMU_LUT70H
    0x002b0501, // GFXMMU_LUT71L
    0x000077a0, // GFXMMU_LUT71H
    0x002b0501, // GFXMMU_LUT72L
    0x00007a10, // GFXMMU_LUT72H
    0x002b0501, // GFXMMU_LUT73L
    0x00007c80, // GFXMMU_LUT73H
    0x002b0501, // GFXMMU_LUT74L
    0x00007ef0, // GFXMMU_LUT74H
    0x002b0501, // GFXMMU_LUT75L
    0x00008160, // GFXMMU_LUT75H
    0x002b0501, // GFXMMU_LUT76L
    0x000083d0, // GFXMMU_LUT76H
    0x002b0501, // GFXMMU_LUT77L
    0x00008640, // GFXMMU_LUT77H
    0x002b0401, // GFXMMU_LUT78L
    0x000088c0, // GFXMMU_LUT78H
    0x002b0401, // GFXMMU_LUT79L
    0x00008b40, // GFXMMU_LUT79H
    0x002c0401, // GFXMMU_LUT80L
    0x00008dc0, // GFXMMU_LUT80H
    0x002c0401, // GFXMMU_LUT81L
    0x00009050, // GFXMMU_LUT81H
    0x002c0401, // GFXMMU_LUT82L
    0x000092e0, // GFXMMU_LUT82H
    0x002c0401, // GFXMMU_LUT83L
    0x00009570, // GFXMMU_LUT83H
    0x002c0401, // GFXMMU_LUT84L
    0x00009800, // GFXMMU_LUT84H
    0x002c0401, // GFXMMU_LUT85L
    0x00009a90, // GFXMMU_LUT85H
    0x002c0401, // GFXMMU_LUT86L
    0x00009d20, // GFXMMU_LUT86H
    0x002c0401, // GFXMMU_LUT87L
    0x00009fb0, // GFXMMU_LUT87H
    0x002c0401, // GFXMMU_LUT88L
    0x0000a240, // GFXMMU_LUT88H
    0x002c0301, // GFXMMU_LUT89L
    0x0000a4e0, // GFXMMU_LUT89H
    0x002c0301, // GFXMMU_LUT90L
    0x0000a780, // GFXMMU_LUT90H
    0x002c0301, // GFXMMU_LUT91L
    0x0000aa20, // GFXMMU_LUT91H
    0x002d0301, // GFXMMU_LUT92L
    0x0000acc0, // GFXMMU_LUT92H
    0x002d0301, // GFXMMU_LUT93L
    0x0000af70, // GFXMMU_LUT93H
    0x002d0301, // GFXMMU_LUT94L
    0x0000b220, // GFXMMU_LUT94H
    0x002d0301, // GFXMMU_LUT95L
    0x0000b4d0, // GFXMMU_LUT95H
    0x002d0301, // GFXMMU_LUT96L
    0x0000b780, // GFXMMU_LUT96H
    0x002d0301, // GFXMMU_LUT97L
    0x0000ba30, // GFXMMU_LUT97H
    0x002d0301, // GFXMMU_LUT98L
    0x0000bce0, // GFXMMU_LUT98H
    0x002d0301, // GFXMMU_LUT99L
    0x0000bf90, // GFXMMU_LUT99H
    0x002d0301, // GFXMMU_LUT100L
    0x0000c240, // GFXMMU_LUT100H
    0x002d0301, // GFXMMU_LUT101L
    0x0000c4f0, // GFXMMU_LUT101H
    0x002d0201, // GFXMMU_LUT102L
    0x0000c7b0, // GFXMMU_LUT102H
    0x002d0201, // GFXMMU_LUT103L
    0x0000ca70, // GFXMMU_LUT103H
    0x002d0201, // GFXMMU_LUT104L
    0x0000cd30, // GFXMMU_LUT104H
    0x002d0201, // GFXMMU_LUT105L
    0x0000cff0, // GFXMMU_LUT105H
    0x002e0201, // GFXMMU_LUT106L
    0x0000d2b0, // GFXMMU_LUT106H
    0x002e0201, // GFXMMU_LUT107L
    0x0000d580, // GFXMMU_LUT107H
    0x002e0201, // GFXMMU_LUT108L
    0x0000d850, // GFXMMU_LUT108H
    0x002e0201, // GFXMMU_LUT109L
    0x0000db20, // GFXMMU_LUT109H
    0x002e0201, // GFXMMU_LUT110L
    0x0000ddf0, // GFXMMU_LUT110H
    0x002e0201, // GFXMMU_LUT111L
    0x0000e0c0, // GFXMMU_LUT111H
    0x002e0201, // GFXMMU_LUT112L
    0x0000e390, // GFXMMU_LUT112H
    0x002e0201, // GFXMMU_LUT113L
    0x0000e660, // GFXMMU_LUT113H
    0x002e0201, // GFXMMU_LUT114L
    0x0000e930, // GFXMMU_LUT114H
    0x002e0201, // GFXMMU_LUT115L
    0x0000ec00, // GFXMMU_LUT115H
    0x002e0201, // GFXMMU_LUT116L
    0x0000eed0, // GFXMMU_LUT116H
    0x002e0201, // GFXMMU_LUT117L
    0x0000f1a0, // GFXMMU_LUT117H
    0x002e0101, // GFXMMU_LUT118L
    0x0000f480, // GFXMMU_LUT118H
    0x002e0101, // GFXMMU_LUT119L
    0x0000f760, // GFXMMU_LUT119H
    0x002e0101, // GFXMMU_LUT120L
    0x0000fa40, // GFXMMU_LUT120H
    0x002e0101, // GFXMMU_LUT121L
    0x0000fd20, // GFXMMU_LUT121H
    0x002e0101, // GFXMMU_LUT122L
    0x00010000, // GFXMMU_LUT122H
    0x002f0101, // GFXMMU_LUT123L
    0x000102e0, // GFXMMU_LUT123H
    0x002f0101, // GFXMMU_LUT124L
    0x000105d0, // GFXMMU_LUT124H
    0x002f0101, // GFXMMU_LUT125L
    0x000108c0, // GFXMMU_LUT125H
    0x002f0101, // GFXMMU_LUT126L
    0x00010bb0, // GFXMMU_LUT126H
    0x002f0101, // GFXMMU_LUT127L
    0x00010ea0, // GFXMMU_LUT127H
    0x002f0101, // GFXMMU_LUT128L
    0x00011190, // GFXMMU_LUT128H
    0x002f0101, // GFXMMU_LUT129L
    0x00011480, // GFXMMU_LUT129H
    0x002f0101, // GFXMMU_LUT130L
    0x00011770, // GFXMMU_LUT130H
    0x002f0101, // GFXMMU_LUT131L
    0x00011a60, // GFXMMU_LUT131H
    0x002f0101, // GFXMMU_LUT132L
    0x00011d50, // GFXMMU_LUT132H
    0x002f0101, // GFXMMU_LUT133L
    0x00012040, // GFXMMU_LUT133H
    0x002f0101, // GFXMMU_LUT134L
    0x00012330, // GFXMMU_LUT134H
    0x002f0101, // GFXMMU_LUT135L
    0x00012620, // GFXMMU_LUT135H
    0x002f0101, // GFXMMU_LUT136L
    0x00012910, // GFXMMU_LUT136H
    0x002f0101, // GFXMMU_LUT137L
    0x00012c00, // GFXMMU_LUT137H
    0x002f0101, // GFXMMU_LUT138L
    0x00012ef0, // GFXMMU_LUT138H
    0x002f0101, // GFXMMU_LUT139L
    0x000131e0, // GFXMMU_LUT139H
    0x002f0101, // GFXMMU_LUT140L
    0x000134d0, // GFXMMU_LUT140H
    0x002f0001, // GFXMMU_LUT141L
    0x000137d0, // GFXMMU_LUT141H
    0x002f0001, // GFXMMU_LUT142L
    0x00013ad0, // GFXMMU_LUT142H
    0x002f0001, // GFXMMU_LUT143L
    0x00013dd0, // GFXMMU_LUT143H
    0x002f0001, // GFXMMU_LUT144L
    0x000140d0, // GFXMMU_LUT144H
    0x002f0001, // GFXMMU_LUT145L
    0x000143d0, // GFXMMU_LUT145H
    0x002f0001, // GFXMMU_LUT146L
    0x000146d0, // GFXMMU_LUT146H
    0x002f0001, // GFXMMU_LUT147L
    0x000149d0, // GFXMMU_LUT147H
    0x002f0001, // GFXMMU_LUT148L
    0x00014cd0, // GFXMMU_LUT148H
    0x00300001, // GFXMMU_LUT149L
    0x00014fd0, // GFXMMU_LUT149H
    0x00300001, // GFXMMU_LUT150L
    0x000152e0, // GFXMMU_LUT150H
    0x00300001, // GFXMMU_LUT151L
    0x000155f0, // GFXMMU_LUT151H
    0x00300001, // GFXMMU_LUT152L
    0x00015900, // GFXMMU_LUT152H
    0x00300001, // GFXMMU_LUT153L
    0x00015c10, // GFXMMU_LUT153H
    0x00300001, // GFXMMU_LUT154L
    0x00015f20, // GFXMMU_LUT154H
    0x00300001, // GFXMMU_LUT155L
    0x00016230, // GFXMMU_LUT155H
    0x00300001, // GFXMMU_LUT156L
    0x00016540, // GFXMMU_LUT156H
    0x00300001, // GFXMMU_LUT157L
    0x00016850, // GFXMMU_LUT157H
    0x00300001, // GFXMMU_LUT158L
    0x00016b60, // GFXMMU_LUT158H
    0x00300001, // GFXMMU_LUT159L
    0x00016e70, // GFXMMU_LUT159H
    0x00300001, // GFXMMU_LUT160L
    0x00017180, // GFXMMU_LUT160H
    0x00300001, // GFXMMU_LUT161L
    0x00017490, // GFXMMU_LUT161H
    0x00300001, // GFXMMU_LUT162L
    0x000177a0, // GFXMMU_LUT162H
    0x00300001, // GFXMMU_LUT163L
    0x00017ab0, // GFXMMU_LUT163H
    0x00300001, // GFXMMU_LUT164L
    0x00017dc0, // GFXMMU_LUT164H
    0x00300001, // GFXMMU_LUT165L
    0x000180d0, // GFXMMU_LUT165H
    0x00300001, // GFXMMU_LUT166L
    0x000183e0, // GFXMMU_LUT166H
    0x00300001, // GFXMMU_LUT167L
    0x000186f0, // GFXMMU_LUT167H
    0x00300001, // GFXMMU_LUT168L
    0x00018a00, // GFXMMU_LUT168H
    0x00300001, // GFXMMU_LUT169L
    0x00018d10, // GFXMMU_LUT169H
    0x00300001, // GFXMMU_LUT170L
    0x00019020, // GFXMMU_LUT170H
    0x00300001, // GFXMMU_LUT171L
    0x00019330, // GFXMMU_LUT171H
    0x00300001, // GFXMMU_LUT172L
    0x00019640, // GFXMMU_LUT172H
    0x00300001, // GFXMMU_LUT173L
    0x00019950, // GFXMMU_LUT173H
    0x00300001, // GFXMMU_LUT174L
    0x00019c60, // GFXMMU_LUT174H
    0x00300001, // GFXMMU_LUT175L
    0x00019f70, // GFXMMU_LUT175H
    0x00300001, // GFXMMU_LUT176L
    0x0001a280, // GFXMMU_LUT176H
    0x00300001, // GFXMMU_LUT177L
    0x0001a590, // GFXMMU_LUT177H
    0x00300001, // GFXMMU_LUT178L
    0x0001a8a0, // GFXMMU_LUT178H
    0x00300001, // GFXMMU_LUT179L
    0x0001abb0, // GFXMMU_LUT179H
    0x00300001, // GFXMMU_LUT180L
    0x0001aec0, // GFXMMU_LUT180H
    0x00300001, // GFXMMU_LUT181L
    0x0001b1d0, // GFXMMU_LUT181H
    0x00300001, // GFXMMU_LUT182L
    0x0001b4e0, // GFXMMU_LUT182H
    0x00300001, // GFXMMU_LUT183L
    0x0001b7f0, // GFXMMU_LUT183H
    0x00300001, // GFXMMU_LUT184L
    0x0001bb00, // GFXMMU_LUT184H
    0x00300001, // GFXMMU_LUT185L
    0x0001be10, // GFXMMU_LUT185H
    0x00300001, // GFXMMU_LUT186L
    0x0001c120, // GFXMMU_LUT186H
    0x00300001, // GFXMMU_LUT187L
    0x0001c430, // GFXMMU_LUT187H
    0x00300001, // GFXMMU_LUT188L
    0x0001c740, // GFXMMU_LUT188H
    0x00300001, // GFXMMU_LUT189L
    0x0001ca50, // GFXMMU_LUT189H
    0x00300001, // GFXMMU_LUT190L
    0x0001cd60, // GFXMMU_LUT190H
    0x00300001, // GFXMMU_LUT191L
    0x0001d070, // GFXMMU_LUT191H
    0x00300001, // GFXMMU_LUT192L
    0x0001d380, // GFXMMU_LUT192H
    0x00300001, // GFXMMU_LUT193L
    0x0001d690, // GFXMMU_LUT193H
    0x00300001, // GFXMMU_LUT194L
    0x0001d9a0, // GFXMMU_LUT194H
    0x00300001, // GFXMMU_LUT195L
    0x0001dcb0, // GFXMMU_LUT195H
    0x00300001, // GFXMMU_LUT196L
    0x0001dfc0, // GFXMMU_LUT196H
    0x00300001, // GFXMMU_LUT197L
    0x0001e2d0, // GFXMMU_LUT197H
    0x00300001, // GFXMMU_LUT198L
    0x0001e5e0, // GFXMMU_LUT198H
    0x00300001, // GFXMMU_LUT199L
    0x0001e8f0, // GFXMMU_LUT199H
    0x00300001, // GFXMMU_LUT200L
    0x0001ec00, // GFXMMU_LUT200H
    0x00300001, // GFXMMU_LUT201L
    0x0001ef10, // GFXMMU_LUT201H
    0x00300001, // GFXMMU_LUT202L
    0x0001f220, // GFXMMU_LUT202H
    0x00300001, // GFXMMU_LUT203L
    0x0001f530, // GFXMMU_LUT203H
    0x00300001, // GFXMMU_LUT204L
    0x0001f840, // GFXMMU_LUT204H
    0x00300001, // GFXMMU_LUT205L
    0x0001fb50, // GFXMMU_LUT205H
    0x00300001, // GFXMMU_LUT206L
    0x0001fe60, // GFXMMU_LUT206H
    0x00300001, // GFXMMU_LUT207L
    0x00020170, // GFXMMU_LUT207H
    0x00300001, // GFXMMU_LUT208L
    0x00020480, // GFXMMU_LUT208H
    0x00300001, // GFXMMU_LUT209L
    0x00020790, // GFXMMU_LUT209H
    0x00300001, // GFXMMU_LUT210L
    0x00020aa0, // GFXMMU_LUT210H
    0x00300001, // GFXMMU_LUT211L
    0x00020db0, // GFXMMU_LUT211H
    0x00300001, // GFXMMU_LUT212L
    0x000210c0, // GFXMMU_LUT212H
    0x00300001, // GFXMMU_LUT213L
    0x000213d0, // GFXMMU_LUT213H
    0x00300001, // GFXMMU_LUT214L
    0x000216e0, // GFXMMU_LUT214H
    0x00300001, // GFXMMU_LUT215L
    0x000219f0, // GFXMMU_LUT215H
    0x00300001, // GFXMMU_LUT216L
    0x00021d00, // GFXMMU_LUT216H
    0x00300001, // GFXMMU_LUT217L
    0x00022010, // GFXMMU_LUT217H
    0x00300001, // GFXMMU_LUT218L
    0x00022320, // GFXMMU_LUT218H
    0x00300001, // GFXMMU_LUT219L
    0x00022630, // GFXMMU_LUT219H
    0x00300001, // GFXMMU_LUT220L
    0x00022940, // GFXMMU_LUT220H
    0x00300001, // GFXMMU_LUT221L
    0x00022c50, // GFXMMU_LUT221H
    0x00300001, // GFXMMU_LUT222L
    0x00022f60, // GFXMMU_LUT222H
    0x00300001, // GFXMMU_LUT223L
    0x00023270, // GFXMMU_LUT223H
    0x00300001, // GFXMMU_LUT224L
    0x00023580, // GFXMMU_LUT224H
    0x00300001, // GFXMMU_LUT225L
    0x00023890, // GFXMMU_LUT225H
    0x00300001, // GFXMMU_LUT226L
    0x00023ba0, // GFXMMU_LUT226H
    0x00300001, // GFXMMU_LUT227L
    0x00023eb0, // GFXMMU_LUT227H
    0x00300001, // GFXMMU_LUT228L
    0x000241c0, // GFXMMU_LUT228H
    0x00300001, // GFXMMU_LUT229L
    0x000244d0, // GFXMMU_LUT229H
    0x00300001, // GFXMMU_LUT230L
    0x000247e0, // GFXMMU_LUT230H
    0x00300001, // GFXMMU_LUT231L
    0x00024af0, // GFXMMU_LUT231H
    0x00300001, // GFXMMU_LUT232L
    0x00024e00, // GFXMMU_LUT232H
    0x00300001, // GFXMMU_LUT233L
    0x00025110, // GFXMMU_LUT233H
    0x00300001, // GFXMMU_LUT234L
    0x00025420, // GFXMMU_LUT234H
    0x00300001, // GFXMMU_LUT235L
    0x00025730, // GFXMMU_LUT235H
    0x00300001, // GFXMMU_LUT236L
    0x00025a40, // GFXMMU_LUT236H
    0x00300001, // GFXMMU_LUT237L
    0x00025d50, // GFXMMU_LUT237H
    0x00300001, // GFXMMU_LUT238L
    0x00026060, // GFXMMU_LUT238H
    0x00300001, // GFXMMU_LUT239L
    0x00026370, // GFXMMU_LUT239H
    0x00300001, // GFXMMU_LUT240L
    0x00026680, // GFXMMU_LUT240H
    0x002f0001, // GFXMMU_LUT241L
    0x00026990, // GFXMMU_LUT241H
    0x002f0001, // GFXMMU_LUT242L
    0x00026c90, // GFXMMU_LUT242H
    0x002f0001, // GFXMMU_LUT243L
    0x00026f90, // GFXMMU_LUT243H
    0x002f0001, // GFXMMU_LUT244L
    0x00027290, // GFXMMU_LUT244H
    0x002f0001, // GFXMMU_LUT245L
    0x00027590, // GFXMMU_LUT245H
    0x002f0001, // GFXMMU_LUT246L
    0x00027890, // GFXMMU_LUT246H
    0x002f0001, // GFXMMU_LUT247L
    0x00027b90, // GFXMMU_LUT247H
    0x002f0001, // GFXMMU_LUT248L
    0x00027e90, // GFXMMU_LUT248H
    0x002f0101, // GFXMMU_LUT249L
    0x00028180, // GFXMMU_LUT249H
    0x002f0101, // GFXMMU_LUT250L
    0x00028470, // GFXMMU_LUT250H
    0x002f0101, // GFXMMU_LUT251L
    0x00028760, // GFXMMU_LUT251H
    0x002f0101, // GFXMMU_LUT252L
    0x00028a50, // GFXMMU_LUT252H
    0x002f0101, // GFXMMU_LUT253L
    0x00028d40, // GFXMMU_LUT253H
    0x002f0101, // GFXMMU_LUT254L
    0x00029030, // GFXMMU_LUT254H
    0x002f0101, // GFXMMU_LUT255L
    0x00029320, // GFXMMU_LUT255H
    0x002f0101, // GFXMMU_LUT256L
    0x00029610, // GFXMMU_LUT256H
    0x002f0101, // GFXMMU_LUT257L
    0x00029900, // GFXMMU_LUT257H
    0x002f0101, // GFXMMU_LUT258L
    0x00029bf0, // GFXMMU_LUT258H
    0x002f0101, // GFXMMU_LUT259L
    0x00029ee0, // GFXMMU_LUT259H
    0x002f0101, // GFXMMU_LUT260L
    0x0002a1d0, // GFXMMU_LUT260H
    0x002f0101, // GFXMMU_LUT261L
    0x0002a4c0, // GFXMMU_LUT261H
    0x002f0101, // GFXMMU_LUT262L
    0x0002a7b0, // GFXMMU_LUT262H
    0x002f0101, // GFXMMU_LUT263L
    0x0002aaa0, // GFXMMU_LUT263H
    0x002f0101, // GFXMMU_LUT264L
    0x0002ad90, // GFXMMU_LUT264H
    0x002f0101, // GFXMMU_LUT265L
    0x0002b080, // GFXMMU_LUT265H
    0x002f0101, // GFXMMU_LUT266L
    0x0002b370, // GFXMMU_LUT266H
    0x002e0101, // GFXMMU_LUT267L
    0x0002b660, // GFXMMU_LUT267H
    0x002e0101, // GFXMMU_LUT268L
    0x0002b940, // GFXMMU_LUT268H
    0x002e0101, // GFXMMU_LUT269L
    0x0002bc20, // GFXMMU_LUT269H
    0x002e0101, // GFXMMU_LUT270L
    0x0002bf00, // GFXMMU_LUT270H
    0x002e0101, // GFXMMU_LUT271L
    0x0002c1e0, // GFXMMU_LUT271H
    0x002e0201, // GFXMMU_LUT272L
    0x0002c4b0, // GFXMMU_LUT272H
    0x002e0201, // GFXMMU_LUT273L
    0x0002c780, // GFXMMU_LUT273H
    0x002e0201, // GFXMMU_LUT274L
    0x0002ca50, // GFXMMU_LUT274H
    0x002e0201, // GFXMMU_LUT275L
    0x0002cd20, // GFXMMU_LUT275H
    0x002e0201, // GFXMMU_LUT276L
    0x0002cff0, // GFXMMU_LUT276H
    0x002e0201, // GFXMMU_LUT277L
    0x0002d2c0, // GFXMMU_LUT277H
    0x002e0201, // GFXMMU_LUT278L
    0x0002d590, // GFXMMU_LUT278H
    0x002e0201, // GFXMMU_LUT279L
    0x0002d860, // GFXMMU_LUT279H
    0x002e0201, // GFXMMU_LUT280L
    0x0002db30, // GFXMMU_LUT280H
    0x002e0201, // GFXMMU_LUT281L
    0x0002de00, // GFXMMU_LUT281H
    0x002e0201, // GFXMMU_LUT282L
    0x0002e0d0, // GFXMMU_LUT282H
    0x002e0201, // GFXMMU_LUT283L
    0x0002e3a0, // GFXMMU_LUT283H
    0x002d0201, // GFXMMU_LUT284L
    0x0002e670, // GFXMMU_LUT284H
    0x002d0201, // GFXMMU_LUT285L
    0x0002e930, // GFXMMU_LUT285H
    0x002d0201, // GFXMMU_LUT286L
    0x0002ebf0, // GFXMMU_LUT286H
    0x002d0201, // GFXMMU_LUT287L
    0x0002eeb0, // GFXMMU_LUT287H
    0x002d0301, // GFXMMU_LUT288L
    0x0002f160, // GFXMMU_LUT288H
    0x002d0301, // GFXMMU_LUT289L
    0x0002f410, // GFXMMU_LUT289H
    0x002d0301, // GFXMMU_LUT290L
    0x0002f6c0, // GFXMMU_LUT290H
    0x002d0301, // GFXMMU_LUT291L
    0x0002f970, // GFXMMU_LUT291H
    0x002d0301, // GFXMMU_LUT292L
    0x0002fc20, // GFXMMU_LUT292H
    0x002d0301, // GFXMMU_LUT293L
    0x0002fed0, // GFXMMU_LUT293H
    0x002d0301, // GFXMMU_LUT294L
    0x00030180, // GFXMMU_LUT294H
    0x002d0301, // GFXMMU_LUT295L
    0x00030430, // GFXMMU_LUT295H
    0x002d0301, // GFXMMU_LUT296L
    0x000306e0, // GFXMMU_LUT296H
    0x002d0301, // GFXMMU_LUT297L
    0x00030990, // GFXMMU_LUT297H
    0x002c0301, // GFXMMU_LUT298L
    0x00030c40, // GFXMMU_LUT298H
    0x002c0301, // GFXMMU_LUT299L
    0x00030ee0, // GFXMMU_LUT299H
    0x002c0301, // GFXMMU_LUT300L
    0x00031180, // GFXMMU_LUT300H
    0x002c0401, // GFXMMU_LUT301L
    0x00031410, // GFXMMU_LUT301H
    0x002c0401, // GFXMMU_LUT302L
    0x000316a0, // GFXMMU_LUT302H
    0x002c0401, // GFXMMU_LUT303L
    0x00031930, // GFXMMU_LUT303H
    0x002c0401, // GFXMMU_LUT304L
    0x00031bc0, // GFXMMU_LUT304H
    0x002c0401, // GFXMMU_LUT305L
    0x00031e50, // GFXMMU_LUT305H
    0x002c0401, // GFXMMU_LUT306L
    0x000320e0, // GFXMMU_LUT306H
    0x002c0401, // GFXMMU_LUT307L
    0x00032370, // GFXMMU_LUT307H
    0x002c0401, // GFXMMU_LUT308L
    0x00032600, // GFXMMU_LUT308H
    0x002c0401, // GFXMMU_LUT309L
    0x00032890, // GFXMMU_LUT309H
    0x002b0401, // GFXMMU_LUT310L
    0x00032b20, // GFXMMU_LUT310H
    0x002b0401, // GFXMMU_LUT311L
    0x00032da0, // GFXMMU_LUT311H
    0x002b0501, // GFXMMU_LUT312L
    0x00033010, // GFXMMU_LUT312H
    0x002b0501, // GFXMMU_LUT313L
    0x00033280, // GFXMMU_LUT313H
    0x002b0501, // GFXMMU_LUT314L
    0x000334f0, // GFXMMU_LUT314H
    0x002b0501, // GFXMMU_LUT315L
    0x00033760, // GFXMMU_LUT315H
    0x002b0501, // GFXMMU_LUT316L
    0x000339d0, // GFXMMU_LUT316H
    0x002b0501, // GFXMMU_LUT317L
    0x00033c40, // GFXMMU_LUT317H
    0x002b0501, // GFXMMU_LUT318L
    0x00033eb0, // GFXMMU_LUT318H
    0x002b0501, // GFXMMU_LUT319L
    0x00034120, // GFXMMU_LUT319H
    0x002a0501, // GFXMMU_LUT320L
    0x00034390, // GFXMMU_LUT320H
    0x002a0501, // GFXMMU_LUT321L
    0x000345f0, // GFXMMU_LUT321H
    0x002a0601, // GFXMMU_LUT322L
    0x00034840, // GFXMMU_LUT322H
    0x002a0601, // GFXMMU_LUT323L
    0x00034a90, // GFXMMU_LUT323H
    0x002a0601, // GFXMMU_LUT324L
    0x00034ce0, // GFXMMU_LUT324H
    0x002a0601, // GFXMMU_LUT325L
    0x00034f30, // GFXMMU_LUT325H
    0x002a0601, // GFXMMU_LUT326L
    0x00035180, // GFXMMU_LUT326H
    0x002a0601, // GFXMMU_LUT327L
    0x000353d0, // GFXMMU_LUT327H
    0x002a0601, // GFXMMU_LUT328L
    0x00035620, // GFXMMU_LUT328H
    0x00290601, // GFXMMU_LUT329L
    0x00035870, // GFXMMU_LUT329H
    0x00290601, // GFXMMU_LUT330L
    0x00035ab0, // GFXMMU_LUT330H
    0x00290701, // GFXMMU_LUT331L
    0x00035ce0, // GFXMMU_LUT331H
    0x00290701, // GFXMMU_LUT332L
    0x00035f10, // GFXMMU_LUT332H
    0x00290701, // GFXMMU_LUT333L
    0x00036140, // GFXMMU_LUT333H
    0x00290701, // GFXMMU_LUT334L
    0x00036370, // GFXMMU_LUT334H
    0x00290701, // GFXMMU_LUT335L
    0x000365a0, // GFXMMU_LUT335H
    0x00290701, // GFXMMU_LUT336L
    0x000367d0, // GFXMMU_LUT336H
    0x00280701, // GFXMMU_LUT337L
    0x00036a00, // GFXMMU_LUT337H
    0x00280701, // GFXMMU_LUT338L
    0x00036c20, // GFXMMU_LUT338H
    0x00280801, // GFXMMU_LUT339L
    0x00036e30, // GFXMMU_LUT339H
    0x00280801, // GFXMMU_LUT340L
    0x00037040, // GFXMMU_LUT340H
    0x00280801, // GFXMMU_LUT341L
    0x00037250, // GFXMMU_LUT341H
    0x00280801, // GFXMMU_LUT342L
    0x00037460, // GFXMMU_LUT342H
    0x00280801, // GFXMMU_LUT343L
    0x00037670, // GFXMMU_LUT343H
    0x00270801, // GFXMMU_LUT344L
    0x00037880, // GFXMMU_LUT344H
    0x00270801, // GFXMMU_LUT345L
    0x00037a80, // GFXMMU_LUT345H
    0x00270901, // GFXMMU_LUT346L
    0x00037c70, // GFXMMU_LUT346H
    0x00270901, // GFXMMU_LUT347L
    0x00037e60, // GFXMMU_LUT347H
    0x00270901, // GFXMMU_LUT348L
    0x00038050, // GFXMMU_LUT348H
    0x00270901, // GFXMMU_LUT349L
    0x00038240, // GFXMMU_LUT349H
    0x00270901, // GFXMMU_LUT350L
    0x00038430, // GFXMMU_LUT350H
    0x00260901, // GFXMMU_LUT351L
    0x00038620, // GFXMMU_LUT351H
    0x00260a01, // GFXMMU_LUT352L
    0x000387f0, // GFXMMU_LUT352H
    0x00260a01, // GFXMMU_LUT353L
    0x000389c0, // GFXMMU_LUT353H
    0x00260a01, // GFXMMU_LUT354L
    0x00038b90, // GFXMMU_LUT354H
    0x00260a01, // GFXMMU_LUT355L
    0x00038d60, // GFXMMU_LUT355H
    0x00250a01, // GFXMMU_LUT356L
    0x00038f30, // GFXMMU_LUT356H
    0x00250a01, // GFXMMU_LUT357L
    0x000390f0, // GFXMMU_LUT357H
    0x00250b01, // GFXMMU_LUT358L
    0x000392a0, // GFXMMU_LUT358H
    0x00250b01, // GFXMMU_LUT359L
    0x00039450, // GFXMMU_LUT359H
    0x00250b01, // GFXMMU_LUT360L
    0x00039600, // GFXMMU_LUT360H
    0x00240b01, // GFXMMU_LUT361L
    0x000397b0, // GFXMMU_LUT361H
    0x00240b01, // GFXMMU_LUT362L
    0x00039950, // GFXMMU_LUT362H
    0x00240c01, // GFXMMU_LUT363L
    0x00039ae0, // GFXMMU_LUT363H
    0x00240c01, // GFXMMU_LUT364L
    0x00039c70, // GFXMMU_LUT364H
    0x00240c01, // GFXMMU_LUT365L
    0x00039e00, // GFXMMU_LUT365H
    0x00230c01, // GFXMMU_LUT366L
    0x00039f90, // GFXMMU_LUT366H
    0x00230d01, // GFXMMU_LUT367L
    0x0003a100, // GFXMMU_LUT367H
    0x00230d01, // GFXMMU_LUT368L
    0x0003a270, // GFXMMU_LUT368H
    0x00230d01, // GFXMMU_LUT369L
    0x0003a3e0, // GFXMMU_LUT369H
    0x00220d01, // GFXMMU_LUT370L
    0x0003a550, // GFXMMU_LUT370H
    0x00220e01, // GFXMMU_LUT371L
    0x0003a6a0, // GFXMMU_LUT371H
    0x00220e01, // GFXMMU_LUT372L
    0x0003a7f0, // GFXMMU_LUT372H
    0x00220e01, // GFXMMU_LUT373L
    0x0003a940, // GFXMMU_LUT373H
    0x00210e01, // GFXMMU_LUT374L
    0x0003aa90, // GFXMMU_LUT374H
    0x00210f01, // GFXMMU_LUT375L
    0x0003abc0, // GFXMMU_LUT375H
    0x00210f01, // GFXMMU_LUT376L
    0x0003acf0, // GFXMMU_LUT376H
    0x00200f01, // GFXMMU_LUT377L
    0x0003ae20, // GFXMMU_LUT377H
    0x00201001, // GFXMMU_LUT378L
    0x0003af30, // GFXMMU_LUT378H
    0x00201001, // GFXMMU_LUT379L
    0x0003b040, // GFXMMU_LUT379H
    0x001f1001, // GFXMMU_LUT380L
    0x0003b150, // GFXMMU_LUT380H
    0x001f1101, // GFXMMU_LUT381L
    0x0003b240, // GFXMMU_LUT381H
    0x001e1101, // GFXMMU_LUT382L
    0x0003b330, // GFXMMU_LUT382H
    0x001e1201, // GFXMMU_LUT383L
    0x0003b400, // GFXMMU_LUT383H
    0x001e1201, // GFXMMU_LUT384L
    0x0003b4d0, // GFXMMU_LUT384H
    0x001d1301, // GFXMMU_LUT385L
    0x0003b590, // GFXMMU_LUT385H
    0x001c1301, // GFXMMU_LUT386L
    0x0003b640, // GFXMMU_LUT386H
    0x001c1401, // GFXMMU_LUT387L
    0x0003b6d0, // GFXMMU_LUT387H
    0x001b1501, // GFXMMU_LUT388L
    0x0003b750, // GFXMMU_LUT388H
    0x001a1601, // GFXMMU_LUT389L
    0x0003b7b0  // GFXMMU_LUT389H
};

#elif ( EW_FRAME_BUFFER_COLOR_FORMAT == EW_FRAME_BUFFER_COLOR_FORMAT_RGB888 )
static const uint32_t gfxmmu_lut_config[GFXMMU_LUT_SIZE] = {
    0x00272101, // GFXMMU_LUT0L
    0x003ffdf0, // GFXMMU_LUT0H
    0x00282001, // GFXMMU_LUT1L
    0x003ffe70, // GFXMMU_LUT1H
    0x002a1e01, // GFXMMU_LUT2L
    0x003fff20, // GFXMMU_LUT2H
    0x002b1d01, // GFXMMU_LUT3L
    0x00000000, // GFXMMU_LUT3H
    0x002c1c01, // GFXMMU_LUT4L
    0x00000100, // GFXMMU_LUT4H
    0x002d1b01, // GFXMMU_LUT5L
    0x00000220, // GFXMMU_LUT5H
    0x002d1b01, // GFXMMU_LUT6L
    0x00000350, // GFXMMU_LUT6H
    0x002e1a01, // GFXMMU_LUT7L
    0x00000490, // GFXMMU_LUT7H
    0x002f1901, // GFXMMU_LUT8L
    0x000005f0, // GFXMMU_LUT8H
    0x002f1901, // GFXMMU_LUT9L
    0x00000760, // GFXMMU_LUT9H
    0x00301801, // GFXMMU_LUT10L
    0x000008e0, // GFXMMU_LUT10H
    0x00301801, // GFXMMU_LUT11L
    0x00000a70, // GFXMMU_LUT11H
    0x00311701, // GFXMMU_LUT12L
    0x00000c10, // GFXMMU_LUT12H
    0x00311701, // GFXMMU_LUT13L
    0x00000dc0, // GFXMMU_LUT13H
    0x00321601, // GFXMMU_LUT14L
    0x00000f80, // GFXMMU_LUT14H
    0x00321601, // GFXMMU_LUT15L
    0x00001150, // GFXMMU_LUT15H
    0x00331501, // GFXMMU_LUT16L
    0x00001330, // GFXMMU_LUT16H
    0x00331501, // GFXMMU_LUT17L
    0x00001520, // GFXMMU_LUT17H
    0x00341501, // GFXMMU_LUT18L
    0x00001710, // GFXMMU_LUT18H
    0x00341401, // GFXMMU_LUT19L
    0x00001920, // GFXMMU_LUT19H
    0x00341401, // GFXMMU_LUT20L
    0x00001b30, // GFXMMU_LUT20H
    0x00351301, // GFXMMU_LUT21L
    0x00001d50, // GFXMMU_LUT21H
    0x00351301, // GFXMMU_LUT22L
    0x00001f80, // GFXMMU_LUT22H
    0x00351301, // GFXMMU_LUT23L
    0x000021b0, // GFXMMU_LUT23H
    0x00361201, // GFXMMU_LUT24L
    0x000023f0, // GFXMMU_LUT24H
    0x00361201, // GFXMMU_LUT25L
    0x00002640, // GFXMMU_LUT25H
    0x00361201, // GFXMMU_LUT26L
    0x00002890, // GFXMMU_LUT26H
    0x00371101, // GFXMMU_LUT27L
    0x00002af0, // GFXMMU_LUT27H
    0x00371101, // GFXMMU_LUT28L
    0x00002d60, // GFXMMU_LUT28H
    0x00371101, // GFXMMU_LUT29L
    0x00002fd0, // GFXMMU_LUT29H
    0x00381001, // GFXMMU_LUT30L
    0x00003250, // GFXMMU_LUT30H
    0x00381001, // GFXMMU_LUT31L
    0x000034e0, // GFXMMU_LUT31H
    0x00381001, // GFXMMU_LUT32L
    0x00003770, // GFXMMU_LUT32H
    0x00381001, // GFXMMU_LUT33L
    0x00003a00, // GFXMMU_LUT33H
    0x00390f01, // GFXMMU_LUT34L
    0x00003ca0, // GFXMMU_LUT34H
    0x00390f01, // GFXMMU_LUT35L
    0x00003f50, // GFXMMU_LUT35H
    0x00390f01, // GFXMMU_LUT36L
    0x00004200, // GFXMMU_LUT36H
    0x003a0f01, // GFXMMU_LUT37L
    0x000044b0, // GFXMMU_LUT37H
    0x003a0e01, // GFXMMU_LUT38L
    0x00004780, // GFXMMU_LUT38H
    0x003a0e01, // GFXMMU_LUT39L
    0x00004a50, // GFXMMU_LUT39H
    0x003a0e01, // GFXMMU_LUT40L
    0x00004d20, // GFXMMU_LUT40H
    0x003b0e01, // GFXMMU_LUT41L
    0x00004ff0, // GFXMMU_LUT41H
    0x003b0d01, // GFXMMU_LUT42L
    0x000052e0, // GFXMMU_LUT42H
    0x003b0d01, // GFXMMU_LUT43L
    0x000055d0, // GFXMMU_LUT43H
    0x003b0d01, // GFXMMU_LUT44L
    0x000058c0, // GFXMMU_LUT44H
    0x003b0d01, // GFXMMU_LUT45L
    0x00005bb0, // GFXMMU_LUT45H
    0x003c0c01, // GFXMMU_LUT46L
    0x00005eb0, // GFXMMU_LUT46H
    0x003c0c01, // GFXMMU_LUT47L
    0x000061c0, // GFXMMU_LUT47H
    0x003c0c01, // GFXMMU_LUT48L
    0x000064d0, // GFXMMU_LUT48H
    0x003c0c01, // GFXMMU_LUT49L
    0x000067e0, // GFXMMU_LUT49H
    0x003d0c01, // GFXMMU_LUT50L
    0x00006af0, // GFXMMU_LUT50H
    0x003d0b01, // GFXMMU_LUT51L
    0x00006e20, // GFXMMU_LUT51H
    0x003d0b01, // GFXMMU_LUT52L
    0x00007150, // GFXMMU_LUT52H
    0x003d0b01, // GFXMMU_LUT53L
    0x00007480, // GFXMMU_LUT53H
    0x003d0b01, // GFXMMU_LUT54L
    0x000077b0, // GFXMMU_LUT54H
    0x003e0b01, // GFXMMU_LUT55L
    0x00007ae0, // GFXMMU_LUT55H
    0x003e0a01, // GFXMMU_LUT56L
    0x00007e30, // GFXMMU_LUT56H
    0x003e0a01, // GFXMMU_LUT57L
    0x00008180, // GFXMMU_LUT57H
    0x003e0a01, // GFXMMU_LUT58L
    0x000084d0, // GFXMMU_LUT58H
    0x003e0a01, // GFXMMU_LUT59L
    0x00008820, // GFXMMU_LUT59H
    0x003e0a01, // GFXMMU_LUT60L
    0x00008b70, // GFXMMU_LUT60H
    0x003f0901, // GFXMMU_LUT61L
    0x00008ed0, // GFXMMU_LUT61H
    0x003f0901, // GFXMMU_LUT62L
    0x00009240, // GFXMMU_LUT62H
    0x003f0901, // GFXMMU_LUT63L
    0x000095b0, // GFXMMU_LUT63H
    0x003f0901, // GFXMMU_LUT64L
    0x00009920, // GFXMMU_LUT64H
    0x003f0901, // GFXMMU_LUT65L
    0x00009c90, // GFXMMU_LUT65H
    0x00400901, // GFXMMU_LUT66L
    0x0000a000, // GFXMMU_LUT66H
    0x00400901, // GFXMMU_LUT67L
    0x0000a380, // GFXMMU_LUT67H
    0x00400801, // GFXMMU_LUT68L
    0x0000a710, // GFXMMU_LUT68H
    0x00400801, // GFXMMU_LUT69L
    0x0000aaa0, // GFXMMU_LUT69H
    0x00400801, // GFXMMU_LUT70L
    0x0000ae30, // GFXMMU_LUT70H
    0x00400801, // GFXMMU_LUT71L
    0x0000b1c0, // GFXMMU_LUT71H
    0x00410801, // GFXMMU_LUT72L
    0x0000b550, // GFXMMU_LUT72H
    0x00410801, // GFXMMU_LUT73L
    0x0000b8f0, // GFXMMU_LUT73H
    0x00410701, // GFXMMU_LUT74L
    0x0000bca0, // GFXMMU_LUT74H
    0x00410701, // GFXMMU_LUT75L
    0x0000c050, // GFXMMU_LUT75H
    0x00410701, // GFXMMU_LUT76L
    0x0000c400, // GFXMMU_LUT76H
    0x00410701, // GFXMMU_LUT77L
    0x0000c7b0, // GFXMMU_LUT77H
    0x00410701, // GFXMMU_LUT78L
    0x0000cb60, // GFXMMU_LUT78H
    0x00410701, // GFXMMU_LUT79L
    0x0000cf10, // GFXMMU_LUT79H
    0x00420601, // GFXMMU_LUT80L
    0x0000d2d0, // GFXMMU_LUT80H
    0x00420601, // GFXMMU_LUT81L
    0x0000d6a0, // GFXMMU_LUT81H
    0x00420601, // GFXMMU_LUT82L
    0x0000da70, // GFXMMU_LUT82H
    0x00420601, // GFXMMU_LUT83L
    0x0000de40, // GFXMMU_LUT83H
    0x00420601, // GFXMMU_LUT84L
    0x0000e210, // GFXMMU_LUT84H
    0x00420601, // GFXMMU_LUT85L
    0x0000e5e0, // GFXMMU_LUT85H
    0x00420601, // GFXMMU_LUT86L
    0x0000e9b0, // GFXMMU_LUT86H
    0x00430601, // GFXMMU_LUT87L
    0x0000ed80, // GFXMMU_LUT87H
    0x00430601, // GFXMMU_LUT88L
    0x0000f160, // GFXMMU_LUT88H
    0x00430501, // GFXMMU_LUT89L
    0x0000f550, // GFXMMU_LUT89H
    0x00430501, // GFXMMU_LUT90L
    0x0000f940, // GFXMMU_LUT90H
    0x00430501, // GFXMMU_LUT91L
    0x0000fd30, // GFXMMU_LUT91H
    0x00430501, // GFXMMU_LUT92L
    0x00010120, // GFXMMU_LUT92H
    0x00430501, // GFXMMU_LUT93L
    0x00010510, // GFXMMU_LUT93H
    0x00430501, // GFXMMU_LUT94L
    0x00010900, // GFXMMU_LUT94H
    0x00440501, // GFXMMU_LUT95L
    0x00010cf0, // GFXMMU_LUT95H
    0x00440501, // GFXMMU_LUT96L
    0x000110f0, // GFXMMU_LUT96H
    0x00440401, // GFXMMU_LUT97L
    0x00011500, // GFXMMU_LUT97H
    0x00440401, // GFXMMU_LUT98L
    0x00011910, // GFXMMU_LUT98H
    0x00440401, // GFXMMU_LUT99L
    0x00011d20, // GFXMMU_LUT99H
    0x00440401, // GFXMMU_LUT100L
    0x00012130, // GFXMMU_LUT100H
    0x00440401, // GFXMMU_LUT101L
    0x00012540, // GFXMMU_LUT101H
    0x00440401, // GFXMMU_LUT102L
    0x00012950, // GFXMMU_LUT102H
    0x00440401, // GFXMMU_LUT103L
    0x00012d60, // GFXMMU_LUT103H
    0x00440401, // GFXMMU_LUT104L
    0x00013170, // GFXMMU_LUT104H
    0x00440401, // GFXMMU_LUT105L
    0x00013580, // GFXMMU_LUT105H
    0x00450301, // GFXMMU_LUT106L
    0x000139a0, // GFXMMU_LUT106H
    0x00450301, // GFXMMU_LUT107L
    0x00013dd0, // GFXMMU_LUT107H
    0x00450301, // GFXMMU_LUT108L
    0x00014200, // GFXMMU_LUT108H
    0x00450301, // GFXMMU_LUT109L
    0x00014630, // GFXMMU_LUT109H
    0x00450301, // GFXMMU_LUT110L
    0x00014a60, // GFXMMU_LUT110H
    0x00450301, // GFXMMU_LUT111L
    0x00014e90, // GFXMMU_LUT111H
    0x00450301, // GFXMMU_LUT112L
    0x000152c0, // GFXMMU_LUT112H
    0x00450301, // GFXMMU_LUT113L
    0x000156f0, // GFXMMU_LUT113H
    0x00450301, // GFXMMU_LUT114L
    0x00015b20, // GFXMMU_LUT114H
    0x00450301, // GFXMMU_LUT115L
    0x00015f50, // GFXMMU_LUT115H
    0x00460301, // GFXMMU_LUT116L
    0x00016380, // GFXMMU_LUT116H
    0x00460301, // GFXMMU_LUT117L
    0x000167c0, // GFXMMU_LUT117H
    0x00460201, // GFXMMU_LUT118L
    0x00016c10, // GFXMMU_LUT118H
    0x00460201, // GFXMMU_LUT119L
    0x00017060, // GFXMMU_LUT119H
    0x00460201, // GFXMMU_LUT120L
    0x000174b0, // GFXMMU_LUT120H
    0x00460201, // GFXMMU_LUT121L
    0x00017900, // GFXMMU_LUT121H
    0x00460201, // GFXMMU_LUT122L
    0x00017d50, // GFXMMU_LUT122H
    0x00460201, // GFXMMU_LUT123L
    0x000181a0, // GFXMMU_LUT123H
    0x00460201, // GFXMMU_LUT124L
    0x000185f0, // GFXMMU_LUT124H
    0x00460201, // GFXMMU_LUT125L
    0x00018a40, // GFXMMU_LUT125H
    0x00460201, // GFXMMU_LUT126L
    0x00018e90, // GFXMMU_LUT126H
    0x00460201, // GFXMMU_LUT127L
    0x000192e0, // GFXMMU_LUT127H
    0x00460201, // GFXMMU_LUT128L
    0x00019730, // GFXMMU_LUT128H
    0x00470201, // GFXMMU_LUT129L
    0x00019b80, // GFXMMU_LUT129H
    0x00470201, // GFXMMU_LUT130L
    0x00019fe0, // GFXMMU_LUT130H
    0x00470201, // GFXMMU_LUT131L
    0x0001a440, // GFXMMU_LUT131H
    0x00470101, // GFXMMU_LUT132L
    0x0001a8b0, // GFXMMU_LUT132H
    0x00470101, // GFXMMU_LUT133L
    0x0001ad20, // GFXMMU_LUT133H
    0x00470101, // GFXMMU_LUT134L
    0x0001b190, // GFXMMU_LUT134H
    0x00470101, // GFXMMU_LUT135L
    0x0001b600, // GFXMMU_LUT135H
    0x00470101, // GFXMMU_LUT136L
    0x0001ba70, // GFXMMU_LUT136H
    0x00470101, // GFXMMU_LUT137L
    0x0001bee0, // GFXMMU_LUT137H
    0x00470101, // GFXMMU_LUT138L
    0x0001c350, // GFXMMU_LUT138H
    0x00470101, // GFXMMU_LUT139L
    0x0001c7c0, // GFXMMU_LUT139H
    0x00470101, // GFXMMU_LUT140L
    0x0001cc30, // GFXMMU_LUT140H
    0x00470101, // GFXMMU_LUT141L
    0x0001d0a0, // GFXMMU_LUT141H
    0x00470101, // GFXMMU_LUT142L
    0x0001d510, // GFXMMU_LUT142H
    0x00470101, // GFXMMU_LUT143L
    0x0001d980, // GFXMMU_LUT143H
    0x00470101, // GFXMMU_LUT144L
    0x0001ddf0, // GFXMMU_LUT144H
    0x00470101, // GFXMMU_LUT145L
    0x0001e260, // GFXMMU_LUT145H
    0x00470101, // GFXMMU_LUT146L
    0x0001e6d0, // GFXMMU_LUT146H
    0x00470101, // GFXMMU_LUT147L
    0x0001eb40, // GFXMMU_LUT147H
    0x00470101, // GFXMMU_LUT148L
    0x0001efb0, // GFXMMU_LUT148H
    0x00480001, // GFXMMU_LUT149L
    0x0001f430, // GFXMMU_LUT149H
    0x00480001, // GFXMMU_LUT150L
    0x0001f8c0, // GFXMMU_LUT150H
    0x00480001, // GFXMMU_LUT151L
    0x0001fd50, // GFXMMU_LUT151H
    0x00480001, // GFXMMU_LUT152L
    0x000201e0, // GFXMMU_LUT152H
    0x00480001, // GFXMMU_LUT153L
    0x00020670, // GFXMMU_LUT153H
    0x00480001, // GFXMMU_LUT154L
    0x00020b00, // GFXMMU_LUT154H
    0x00480001, // GFXMMU_LUT155L
    0x00020f90, // GFXMMU_LUT155H
    0x00480001, // GFXMMU_LUT156L
    0x00021420, // GFXMMU_LUT156H
    0x00480001, // GFXMMU_LUT157L
    0x000218b0, // GFXMMU_LUT157H
    0x00480001, // GFXMMU_LUT158L
    0x00021d40, // GFXMMU_LUT158H
    0x00480001, // GFXMMU_LUT159L
    0x000221d0, // GFXMMU_LUT159H
    0x00480001, // GFXMMU_LUT160L
    0x00022660, // GFXMMU_LUT160H
    0x00480001, // GFXMMU_LUT161L
    0x00022af0, // GFXMMU_LUT161H
    0x00480001, // GFXMMU_LUT162L
    0x00022f80, // GFXMMU_LUT162H
    0x00480001, // GFXMMU_LUT163L
    0x00023410, // GFXMMU_LUT163H
    0x00480001, // GFXMMU_LUT164L
    0x000238a0, // GFXMMU_LUT164H
    0x00480001, // GFXMMU_LUT165L
    0x00023d30, // GFXMMU_LUT165H
    0x00480001, // GFXMMU_LUT166L
    0x000241c0, // GFXMMU_LUT166H
    0x00480001, // GFXMMU_LUT167L
    0x00024650, // GFXMMU_LUT167H
    0x00480001, // GFXMMU_LUT168L
    0x00024ae0, // GFXMMU_LUT168H
    0x00480001, // GFXMMU_LUT169L
    0x00024f70, // GFXMMU_LUT169H
    0x00480001, // GFXMMU_LUT170L
    0x00025400, // GFXMMU_LUT170H
    0x00480001, // GFXMMU_LUT171L
    0x00025890, // GFXMMU_LUT171H
    0x00480001, // GFXMMU_LUT172L
    0x00025d20, // GFXMMU_LUT172H
    0x00480001, // GFXMMU_LUT173L
    0x000261b0, // GFXMMU_LUT173H
    0x00480001, // GFXMMU_LUT174L
    0x00026640, // GFXMMU_LUT174H
    0x00480001, // GFXMMU_LUT175L
    0x00026ad0, // GFXMMU_LUT175H
    0x00480001, // GFXMMU_LUT176L
    0x00026f60, // GFXMMU_LUT176H
    0x00480001, // GFXMMU_LUT177L
    0x000273f0, // GFXMMU_LUT177H
    0x00480001, // GFXMMU_LUT178L
    0x00027880, // GFXMMU_LUT178H
    0x00480001, // GFXMMU_LUT179L
    0x00027d10, // GFXMMU_LUT179H
    0x00480001, // GFXMMU_LUT180L
    0x000281a0, // GFXMMU_LUT180H
    0x00490001, // GFXMMU_LUT181L
    0x00028630, // GFXMMU_LUT181H
    0x00490001, // GFXMMU_LUT182L
    0x00028ad0, // GFXMMU_LUT182H
    0x00490001, // GFXMMU_LUT183L
    0x00028f70, // GFXMMU_LUT183H
    0x00490001, // GFXMMU_LUT184L
    0x00029410, // GFXMMU_LUT184H
    0x00490001, // GFXMMU_LUT185L
    0x000298b0, // GFXMMU_LUT185H
    0x00490001, // GFXMMU_LUT186L
    0x00029d50, // GFXMMU_LUT186H
    0x00490001, // GFXMMU_LUT187L
    0x0002a1f0, // GFXMMU_LUT187H
    0x00490001, // GFXMMU_LUT188L
    0x0002a690, // GFXMMU_LUT188H
    0x00490001, // GFXMMU_LUT189L
    0x0002ab30, // GFXMMU_LUT189H
    0x00490001, // GFXMMU_LUT190L
    0x0002afd0, // GFXMMU_LUT190H
    0x00490001, // GFXMMU_LUT191L
    0x0002b470, // GFXMMU_LUT191H
    0x00490001, // GFXMMU_LUT192L
    0x0002b910, // GFXMMU_LUT192H
    0x00490001, // GFXMMU_LUT193L
    0x0002bdb0, // GFXMMU_LUT193H
    0x00490001, // GFXMMU_LUT194L
    0x0002c250, // GFXMMU_LUT194H
    0x00490001, // GFXMMU_LUT195L
    0x0002c6f0, // GFXMMU_LUT195H
    0x00490001, // GFXMMU_LUT196L
    0x0002cb90, // GFXMMU_LUT196H
    0x00490001, // GFXMMU_LUT197L
    0x0002d030, // GFXMMU_LUT197H
    0x00490001, // GFXMMU_LUT198L
    0x0002d4d0, // GFXMMU_LUT198H
    0x00490001, // GFXMMU_LUT199L
    0x0002d970, // GFXMMU_LUT199H
    0x00490001, // GFXMMU_LUT200L
    0x0002de10, // GFXMMU_LUT200H
    0x00490001, // GFXMMU_LUT201L
    0x0002e2b0, // GFXMMU_LUT201H
    0x00490001, // GFXMMU_LUT202L
    0x0002e750, // GFXMMU_LUT202H
    0x00490001, // GFXMMU_LUT203L
    0x0002ebf0, // GFXMMU_LUT203H
    0x00490001, // GFXMMU_LUT204L
    0x0002f090, // GFXMMU_LUT204H
    0x00490001, // GFXMMU_LUT205L
    0x0002f530, // GFXMMU_LUT205H
    0x00490001, // GFXMMU_LUT206L
    0x0002f9d0, // GFXMMU_LUT206H
    0x00490001, // GFXMMU_LUT207L
    0x0002fe70, // GFXMMU_LUT207H
    0x00490001, // GFXMMU_LUT208L
    0x00030310, // GFXMMU_LUT208H
    0x00480001, // GFXMMU_LUT209L
    0x000307b0, // GFXMMU_LUT209H
    0x00480001, // GFXMMU_LUT210L
    0x00030c40, // GFXMMU_LUT210H
    0x00480001, // GFXMMU_LUT211L
    0x000310d0, // GFXMMU_LUT211H
    0x00480001, // GFXMMU_LUT212L
    0x00031560, // GFXMMU_LUT212H
    0x00480001, // GFXMMU_LUT213L
    0x000319f0, // GFXMMU_LUT213H
    0x00480001, // GFXMMU_LUT214L
    0x00031e80, // GFXMMU_LUT214H
    0x00480001, // GFXMMU_LUT215L
    0x00032310, // GFXMMU_LUT215H
    0x00480001, // GFXMMU_LUT216L
    0x000327a0, // GFXMMU_LUT216H
    0x00480001, // GFXMMU_LUT217L
    0x00032c30, // GFXMMU_LUT217H
    0x00480001, // GFXMMU_LUT218L
    0x000330c0, // GFXMMU_LUT218H
    0x00480001, // GFXMMU_LUT219L
    0x00033550, // GFXMMU_LUT219H
    0x00480001, // GFXMMU_LUT220L
    0x000339e0, // GFXMMU_LUT220H
    0x00480001, // GFXMMU_LUT221L
    0x00033e70, // GFXMMU_LUT221H
    0x00480001, // GFXMMU_LUT222L
    0x00034300, // GFXMMU_LUT222H
    0x00480001, // GFXMMU_LUT223L
    0x00034790, // GFXMMU_LUT223H
    0x00480001, // GFXMMU_LUT224L
    0x00034c20, // GFXMMU_LUT224H
    0x00480001, // GFXMMU_LUT225L
    0x000350b0, // GFXMMU_LUT225H
    0x00480001, // GFXMMU_LUT226L
    0x00035540, // GFXMMU_LUT226H
    0x00480001, // GFXMMU_LUT227L
    0x000359d0, // GFXMMU_LUT227H
    0x00480001, // GFXMMU_LUT228L
    0x00035e60, // GFXMMU_LUT228H
    0x00480001, // GFXMMU_LUT229L
    0x000362f0, // GFXMMU_LUT229H
    0x00480001, // GFXMMU_LUT230L
    0x00036780, // GFXMMU_LUT230H
    0x00480001, // GFXMMU_LUT231L
    0x00036c10, // GFXMMU_LUT231H
    0x00480001, // GFXMMU_LUT232L
    0x000370a0, // GFXMMU_LUT232H
    0x00480001, // GFXMMU_LUT233L
    0x00037530, // GFXMMU_LUT233H
    0x00480001, // GFXMMU_LUT234L
    0x000379c0, // GFXMMU_LUT234H
    0x00480001, // GFXMMU_LUT235L
    0x00037e50, // GFXMMU_LUT235H
    0x00480001, // GFXMMU_LUT236L
    0x000382e0, // GFXMMU_LUT236H
    0x00480001, // GFXMMU_LUT237L
    0x00038770, // GFXMMU_LUT237H
    0x00480001, // GFXMMU_LUT238L
    0x00038c00, // GFXMMU_LUT238H
    0x00480001, // GFXMMU_LUT239L
    0x00039090, // GFXMMU_LUT239H
    0x00480001, // GFXMMU_LUT240L
    0x00039520, // GFXMMU_LUT240H
    0x00470101, // GFXMMU_LUT241L
    0x000399a0, // GFXMMU_LUT241H
    0x00470101, // GFXMMU_LUT242L
    0x00039e10, // GFXMMU_LUT242H
    0x00470101, // GFXMMU_LUT243L
    0x0003a280, // GFXMMU_LUT243H
    0x00470101, // GFXMMU_LUT244L
    0x0003a6f0, // GFXMMU_LUT244H
    0x00470101, // GFXMMU_LUT245L
    0x0003ab60, // GFXMMU_LUT245H
    0x00470101, // GFXMMU_LUT246L
    0x0003afd0, // GFXMMU_LUT246H
    0x00470101, // GFXMMU_LUT247L
    0x0003b440, // GFXMMU_LUT247H
    0x00470101, // GFXMMU_LUT248L
    0x0003b8b0, // GFXMMU_LUT248H
    0x00470101, // GFXMMU_LUT249L
    0x0003bd20, // GFXMMU_LUT249H
    0x00470101, // GFXMMU_LUT250L
    0x0003c190, // GFXMMU_LUT250H
    0x00470101, // GFXMMU_LUT251L
    0x0003c600, // GFXMMU_LUT251H
    0x00470101, // GFXMMU_LUT252L
    0x0003ca70, // GFXMMU_LUT252H
    0x00470101, // GFXMMU_LUT253L
    0x0003cee0, // GFXMMU_LUT253H
    0x00470101, // GFXMMU_LUT254L
    0x0003d350, // GFXMMU_LUT254H
    0x00470101, // GFXMMU_LUT255L
    0x0003d7c0, // GFXMMU_LUT255H
    0x00470101, // GFXMMU_LUT256L
    0x0003dc30, // GFXMMU_LUT256H
    0x00470101, // GFXMMU_LUT257L
    0x0003e0a0, // GFXMMU_LUT257H
    0x00470201, // GFXMMU_LUT258L
    0x0003e500, // GFXMMU_LUT258H
    0x00470201, // GFXMMU_LUT259L
    0x0003e960, // GFXMMU_LUT259H
    0x00470201, // GFXMMU_LUT260L
    0x0003edc0, // GFXMMU_LUT260H
    0x00460201, // GFXMMU_LUT261L
    0x0003f220, // GFXMMU_LUT261H
    0x00460201, // GFXMMU_LUT262L
    0x0003f670, // GFXMMU_LUT262H
    0x00460201, // GFXMMU_LUT263L
    0x0003fac0, // GFXMMU_LUT263H
    0x00460201, // GFXMMU_LUT264L
    0x0003ff10, // GFXMMU_LUT264H
    0x00460201, // GFXMMU_LUT265L
    0x00040360, // GFXMMU_LUT265H
    0x00460201, // GFXMMU_LUT266L
    0x000407b0, // GFXMMU_LUT266H
    0x00460201, // GFXMMU_LUT267L
    0x00040c00, // GFXMMU_LUT267H
    0x00460201, // GFXMMU_LUT268L
    0x00041050, // GFXMMU_LUT268H
    0x00460201, // GFXMMU_LUT269L
    0x000414a0, // GFXMMU_LUT269H
    0x00460201, // GFXMMU_LUT270L
    0x000418f0, // GFXMMU_LUT270H
    0x00460201, // GFXMMU_LUT271L
    0x00041d40, // GFXMMU_LUT271H
    0x00460301, // GFXMMU_LUT272L
    0x00042180, // GFXMMU_LUT272H
    0x00460301, // GFXMMU_LUT273L
    0x000425c0, // GFXMMU_LUT273H
    0x00450301, // GFXMMU_LUT274L
    0x00042a00, // GFXMMU_LUT274H
    0x00450301, // GFXMMU_LUT275L
    0x00042e30, // GFXMMU_LUT275H
    0x00450301, // GFXMMU_LUT276L
    0x00043260, // GFXMMU_LUT276H
    0x00450301, // GFXMMU_LUT277L
    0x00043690, // GFXMMU_LUT277H
    0x00450301, // GFXMMU_LUT278L
    0x00043ac0, // GFXMMU_LUT278H
    0x00450301, // GFXMMU_LUT279L
    0x00043ef0, // GFXMMU_LUT279H
    0x00450301, // GFXMMU_LUT280L
    0x00044320, // GFXMMU_LUT280H
    0x00450301, // GFXMMU_LUT281L
    0x00044750, // GFXMMU_LUT281H
    0x00450301, // GFXMMU_LUT282L
    0x00044b80, // GFXMMU_LUT282H
    0x00450301, // GFXMMU_LUT283L
    0x00044fb0, // GFXMMU_LUT283H
    0x00440401, // GFXMMU_LUT284L
    0x000453d0, // GFXMMU_LUT284H
    0x00440401, // GFXMMU_LUT285L
    0x000457e0, // GFXMMU_LUT285H
    0x00440401, // GFXMMU_LUT286L
    0x00045bf0, // GFXMMU_LUT286H
    0x00440401, // GFXMMU_LUT287L
    0x00046000, // GFXMMU_LUT287H
    0x00440401, // GFXMMU_LUT288L
    0x00046410, // GFXMMU_LUT288H
    0x00440401, // GFXMMU_LUT289L
    0x00046820, // GFXMMU_LUT289H
    0x00440401, // GFXMMU_LUT290L
    0x00046c30, // GFXMMU_LUT290H
    0x00440401, // GFXMMU_LUT291L
    0x00047040, // GFXMMU_LUT291H
    0x00440401, // GFXMMU_LUT292L
    0x00047450, // GFXMMU_LUT292H
    0x00440501, // GFXMMU_LUT293L
    0x00047850, // GFXMMU_LUT293H
    0x00440501, // GFXMMU_LUT294L
    0x00047c50, // GFXMMU_LUT294H
    0x00430501, // GFXMMU_LUT295L
    0x00048050, // GFXMMU_LUT295H
    0x00430501, // GFXMMU_LUT296L
    0x00048440, // GFXMMU_LUT296H
    0x00430501, // GFXMMU_LUT297L
    0x00048830, // GFXMMU_LUT297H
    0x00430501, // GFXMMU_LUT298L
    0x00048c20, // GFXMMU_LUT298H
    0x00430501, // GFXMMU_LUT299L
    0x00049010, // GFXMMU_LUT299H
    0x00430501, // GFXMMU_LUT300L
    0x00049400, // GFXMMU_LUT300H
    0x00430601, // GFXMMU_LUT301L
    0x000497e0, // GFXMMU_LUT301H
    0x00430601, // GFXMMU_LUT302L
    0x00049bc0, // GFXMMU_LUT302H
    0x00420601, // GFXMMU_LUT303L
    0x00049fa0, // GFXMMU_LUT303H
    0x00420601, // GFXMMU_LUT304L
    0x0004a370, // GFXMMU_LUT304H
    0x00420601, // GFXMMU_LUT305L
    0x0004a740, // GFXMMU_LUT305H
    0x00420601, // GFXMMU_LUT306L
    0x0004ab10, // GFXMMU_LUT306H
    0x00420601, // GFXMMU_LUT307L
    0x0004aee0, // GFXMMU_LUT307H
    0x00420601, // GFXMMU_LUT308L
    0x0004b2b0, // GFXMMU_LUT308H
    0x00420601, // GFXMMU_LUT309L
    0x0004b680, // GFXMMU_LUT309H
    0x00410701, // GFXMMU_LUT310L
    0x0004ba40, // GFXMMU_LUT310H
    0x00410701, // GFXMMU_LUT311L
    0x0004bdf0, // GFXMMU_LUT311H
    0x00410701, // GFXMMU_LUT312L
    0x0004c1a0, // GFXMMU_LUT312H
    0x00410701, // GFXMMU_LUT313L
    0x0004c550, // GFXMMU_LUT313H
    0x00410701, // GFXMMU_LUT314L
    0x0004c900, // GFXMMU_LUT314H
    0x00410701, // GFXMMU_LUT315L
    0x0004ccb0, // GFXMMU_LUT315H
    0x00410801, // GFXMMU_LUT316L
    0x0004d050, // GFXMMU_LUT316H
    0x00410801, // GFXMMU_LUT317L
    0x0004d3f0, // GFXMMU_LUT317H
    0x00400801, // GFXMMU_LUT318L
    0x0004d790, // GFXMMU_LUT318H
    0x00400801, // GFXMMU_LUT319L
    0x0004db20, // GFXMMU_LUT319H
    0x00400801, // GFXMMU_LUT320L
    0x0004deb0, // GFXMMU_LUT320H
    0x00400801, // GFXMMU_LUT321L
    0x0004e240, // GFXMMU_LUT321H
    0x00400901, // GFXMMU_LUT322L
    0x0004e5c0, // GFXMMU_LUT322H
    0x00400901, // GFXMMU_LUT323L
    0x0004e940, // GFXMMU_LUT323H
    0x003f0901, // GFXMMU_LUT324L
    0x0004ecc0, // GFXMMU_LUT324H
    0x003f0901, // GFXMMU_LUT325L
    0x0004f030, // GFXMMU_LUT325H
    0x003f0901, // GFXMMU_LUT326L
    0x0004f3a0, // GFXMMU_LUT326H
    0x003f0901, // GFXMMU_LUT327L
    0x0004f710, // GFXMMU_LUT327H
    0x003f0901, // GFXMMU_LUT328L
    0x0004fa80, // GFXMMU_LUT328H
    0x003e0a01, // GFXMMU_LUT329L
    0x0004fde0, // GFXMMU_LUT329H
    0x003e0a01, // GFXMMU_LUT330L
    0x00050130, // GFXMMU_LUT330H
    0x003e0a01, // GFXMMU_LUT331L
    0x00050480, // GFXMMU_LUT331H
    0x003e0a01, // GFXMMU_LUT332L
    0x000507d0, // GFXMMU_LUT332H
    0x003e0a01, // GFXMMU_LUT333L
    0x00050b20, // GFXMMU_LUT333H
    0x003e0b01, // GFXMMU_LUT334L
    0x00050e60, // GFXMMU_LUT334H
    0x003d0b01, // GFXMMU_LUT335L
    0x000511a0, // GFXMMU_LUT335H
    0x003d0b01, // GFXMMU_LUT336L
    0x000514d0, // GFXMMU_LUT336H
    0x003d0b01, // GFXMMU_LUT337L
    0x00051800, // GFXMMU_LUT337H
    0x003d0b01, // GFXMMU_LUT338L
    0x00051b30, // GFXMMU_LUT338H
    0x003d0c01, // GFXMMU_LUT339L
    0x00051e50, // GFXMMU_LUT339H
    0x003c0c01, // GFXMMU_LUT340L
    0x00052170, // GFXMMU_LUT340H
    0x003c0c01, // GFXMMU_LUT341L
    0x00052480, // GFXMMU_LUT341H
    0x003c0c01, // GFXMMU_LUT342L
    0x00052790, // GFXMMU_LUT342H
    0x003c0c01, // GFXMMU_LUT343L
    0x00052aa0, // GFXMMU_LUT343H
    0x003b0d01, // GFXMMU_LUT344L
    0x00052da0, // GFXMMU_LUT344H
    0x003b0d01, // GFXMMU_LUT345L
    0x00053090, // GFXMMU_LUT345H
    0x003b0d01, // GFXMMU_LUT346L
    0x00053380, // GFXMMU_LUT346H
    0x003b0d01, // GFXMMU_LUT347L
    0x00053670, // GFXMMU_LUT347H
    0x003b0e01, // GFXMMU_LUT348L
    0x00053950, // GFXMMU_LUT348H
    0x003a0e01, // GFXMMU_LUT349L
    0x00053c30, // GFXMMU_LUT349H
    0x003a0e01, // GFXMMU_LUT350L
    0x00053f00, // GFXMMU_LUT350H
    0x003a0e01, // GFXMMU_LUT351L
    0x000541d0, // GFXMMU_LUT351H
    0x003a0f01, // GFXMMU_LUT352L
    0x00054490, // GFXMMU_LUT352H
    0x00390f01, // GFXMMU_LUT353L
    0x00054750, // GFXMMU_LUT353H
    0x00390f01, // GFXMMU_LUT354L
    0x00054a00, // GFXMMU_LUT354H
    0x00390f01, // GFXMMU_LUT355L
    0x00054cb0, // GFXMMU_LUT355H
    0x00381001, // GFXMMU_LUT356L
    0x00054f50, // GFXMMU_LUT356H
    0x00381001, // GFXMMU_LUT357L
    0x000551e0, // GFXMMU_LUT357H
    0x00381001, // GFXMMU_LUT358L
    0x00055470, // GFXMMU_LUT358H
    0x00381001, // GFXMMU_LUT359L
    0x00055700, // GFXMMU_LUT359H
    0x00371101, // GFXMMU_LUT360L
    0x00055980, // GFXMMU_LUT360H
    0x00371101, // GFXMMU_LUT361L
    0x00055bf0, // GFXMMU_LUT361H
    0x00371101, // GFXMMU_LUT362L
    0x00055e60, // GFXMMU_LUT362H
    0x00361201, // GFXMMU_LUT363L
    0x000560c0, // GFXMMU_LUT363H
    0x00361201, // GFXMMU_LUT364L
    0x00056310, // GFXMMU_LUT364H
    0x00361201, // GFXMMU_LUT365L
    0x00056560, // GFXMMU_LUT365H
    0x00351301, // GFXMMU_LUT366L
    0x000567a0, // GFXMMU_LUT366H
    0x00351301, // GFXMMU_LUT367L
    0x000569d0, // GFXMMU_LUT367H
    0x00351301, // GFXMMU_LUT368L
    0x00056c00, // GFXMMU_LUT368H
    0x00341401, // GFXMMU_LUT369L
    0x00056e20, // GFXMMU_LUT369H
    0x00341401, // GFXMMU_LUT370L
    0x00057030, // GFXMMU_LUT370H
    0x00341501, // GFXMMU_LUT371L
    0x00057230, // GFXMMU_LUT371H
    0x00331501, // GFXMMU_LUT372L
    0x00057430, // GFXMMU_LUT372H
    0x00331501, // GFXMMU_LUT373L
    0x00057620, // GFXMMU_LUT373H
    0x00321601, // GFXMMU_LUT374L
    0x00057800, // GFXMMU_LUT374H
    0x00321601, // GFXMMU_LUT375L
    0x000579d0, // GFXMMU_LUT375H
    0x00311701, // GFXMMU_LUT376L
    0x00057b90, // GFXMMU_LUT376H
    0x00311701, // GFXMMU_LUT377L
    0x00057d40, // GFXMMU_LUT377H
    0x00301801, // GFXMMU_LUT378L
    0x00057ee0, // GFXMMU_LUT378H
    0x00301801, // GFXMMU_LUT379L
    0x00058070, // GFXMMU_LUT379H
    0x002f1901, // GFXMMU_LUT380L
    0x000581f0, // GFXMMU_LUT380H
    0x002f1901, // GFXMMU_LUT381L
    0x00058360, // GFXMMU_LUT381H
    0x002e1a01, // GFXMMU_LUT382L
    0x000584c0, // GFXMMU_LUT382H
    0x002d1b01, // GFXMMU_LUT383L
    0x00058600, // GFXMMU_LUT383H
    0x002d1b01, // GFXMMU_LUT384L
    0x00058730, // GFXMMU_LUT384H
    0x002c1c01, // GFXMMU_LUT385L
    0x00058850, // GFXMMU_LUT385H
    0x002b1d01, // GFXMMU_LUT386L
    0x00058950, // GFXMMU_LUT386H
    0x002a1e01, // GFXMMU_LUT387L
    0x00058a30, // GFXMMU_LUT387H
    0x00282001, // GFXMMU_LUT388L
    0x00058ae0, // GFXMMU_LUT388H
    0x00272101, // GFXMMU_LUT389L
    0x00058b60  // GFXMMU_LUT389H
};

#elif ( EW_FRAME_BUFFER_COLOR_FORMAT == EW_FRAME_BUFFER_COLOR_FORMAT_RGBA8888 )
/* GFXMMU look-up table for ARGB888 */
static const uint32_t gfxmmu_lut_config[GFXMMU_LUT_SIZE] = {
    0x00342d01, // GFXMMU_LUT0L
    0x003ffd30, // GFXMMU_LUT0H
    0x00362b01, // GFXMMU_LUT1L
    0x003ffdd0, // GFXMMU_LUT1H
    0x00382901, // GFXMMU_LUT2L
    0x003ffeb0, // GFXMMU_LUT2H
    0x00392701, // GFXMMU_LUT3L
    0x003fffd0, // GFXMMU_LUT3H
    0x003b2601, // GFXMMU_LUT4L
    0x00000110, // GFXMMU_LUT4H
    0x003c2501, // GFXMMU_LUT5L
    0x00000280, // GFXMMU_LUT5H
    0x003d2401, // GFXMMU_LUT6L
    0x00000410, // GFXMMU_LUT6H
    0x003d2301, // GFXMMU_LUT7L
    0x000005c0, // GFXMMU_LUT7H
    0x003e2201, // GFXMMU_LUT8L
    0x00000780, // GFXMMU_LUT8H
    0x003f2101, // GFXMMU_LUT9L
    0x00000960, // GFXMMU_LUT9H
    0x00402101, // GFXMMU_LUT10L
    0x00000b50, // GFXMMU_LUT10H
    0x00402001, // GFXMMU_LUT11L
    0x00000d60, // GFXMMU_LUT11H
    0x00411f01, // GFXMMU_LUT12L
    0x00000f80, // GFXMMU_LUT12H
    0x00421f01, // GFXMMU_LUT13L
    0x000011b0, // GFXMMU_LUT13H
    0x00431e01, // GFXMMU_LUT14L
    0x00001400, // GFXMMU_LUT14H
    0x00431d01, // GFXMMU_LUT15L
    0x00001670, // GFXMMU_LUT15H
    0x00441d01, // GFXMMU_LUT16L
    0x000018e0, // GFXMMU_LUT16H
    0x00441c01, // GFXMMU_LUT17L
    0x00001b70, // GFXMMU_LUT17H
    0x00451c01, // GFXMMU_LUT18L
    0x00001e00, // GFXMMU_LUT18H
    0x00451b01, // GFXMMU_LUT19L
    0x000020b0, // GFXMMU_LUT19H
    0x00461b01, // GFXMMU_LUT20L
    0x00002360, // GFXMMU_LUT20H
    0x00461a01, // GFXMMU_LUT21L
    0x00002630, // GFXMMU_LUT21H
    0x00471a01, // GFXMMU_LUT22L
    0x00002900, // GFXMMU_LUT22H
    0x00471901, // GFXMMU_LUT23L
    0x00002bf0, // GFXMMU_LUT23H
    0x00481901, // GFXMMU_LUT24L
    0x00002ee0, // GFXMMU_LUT24H
    0x00481801, // GFXMMU_LUT25L
    0x000031f0, // GFXMMU_LUT25H
    0x00491801, // GFXMMU_LUT26L
    0x00003500, // GFXMMU_LUT26H
    0x00491701, // GFXMMU_LUT27L
    0x00003830, // GFXMMU_LUT27H
    0x00491701, // GFXMMU_LUT28L
    0x00003b60, // GFXMMU_LUT28H
    0x004a1701, // GFXMMU_LUT29L
    0x00003e90, // GFXMMU_LUT29H
    0x004a1601, // GFXMMU_LUT30L
    0x000041e0, // GFXMMU_LUT30H
    0x004b1601, // GFXMMU_LUT31L
    0x00004530, // GFXMMU_LUT31H
    0x004b1501, // GFXMMU_LUT32L
    0x000048a0, // GFXMMU_LUT32H
    0x004b1501, // GFXMMU_LUT33L
    0x00004c10, // GFXMMU_LUT33H
    0x004c1501, // GFXMMU_LUT34L
    0x00004f80, // GFXMMU_LUT34H
    0x004c1401, // GFXMMU_LUT35L
    0x00005310, // GFXMMU_LUT35H
    0x004c1401, // GFXMMU_LUT36L
    0x000056a0, // GFXMMU_LUT36H
    0x004d1401, // GFXMMU_LUT37L
    0x00005a30, // GFXMMU_LUT37H
    0x004d1301, // GFXMMU_LUT38L
    0x00005de0, // GFXMMU_LUT38H
    0x004e1301, // GFXMMU_LUT39L
    0x00006190, // GFXMMU_LUT39H
    0x004e1301, // GFXMMU_LUT40L
    0x00006550, // GFXMMU_LUT40H
    0x004e1201, // GFXMMU_LUT41L
    0x00006920, // GFXMMU_LUT41H
    0x004e1201, // GFXMMU_LUT42L
    0x00006cf0, // GFXMMU_LUT42H
    0x004f1201, // GFXMMU_LUT43L
    0x000070c0, // GFXMMU_LUT43H
    0x004f1101, // GFXMMU_LUT44L
    0x000074b0, // GFXMMU_LUT44H
    0x004f1101, // GFXMMU_LUT45L
    0x000078a0, // GFXMMU_LUT45H
    0x00501101, // GFXMMU_LUT46L
    0x00007c90, // GFXMMU_LUT46H
    0x00501101, // GFXMMU_LUT47L
    0x00008090, // GFXMMU_LUT47H
    0x00501001, // GFXMMU_LUT48L
    0x000084a0, // GFXMMU_LUT48H
    0x00511001, // GFXMMU_LUT49L
    0x000088b0, // GFXMMU_LUT49H
    0x00511001, // GFXMMU_LUT50L
    0x00008cd0, // GFXMMU_LUT50H
    0x00510f01, // GFXMMU_LUT51L
    0x00009100, // GFXMMU_LUT51H
    0x00510f01, // GFXMMU_LUT52L
    0x00009530, // GFXMMU_LUT52H
    0x00520f01, // GFXMMU_LUT53L
    0x00009960, // GFXMMU_LUT53H
    0x00520f01, // GFXMMU_LUT54L
    0x00009da0, // GFXMMU_LUT54H
    0x00520e01, // GFXMMU_LUT55L
    0x0000a1f0, // GFXMMU_LUT55H
    0x00520e01, // GFXMMU_LUT56L
    0x0000a640, // GFXMMU_LUT56H
    0x00530e01, // GFXMMU_LUT57L
    0x0000aa90, // GFXMMU_LUT57H
    0x00530e01, // GFXMMU_LUT58L
    0x0000aef0, // GFXMMU_LUT58H
    0x00530d01, // GFXMMU_LUT59L
    0x0000b360, // GFXMMU_LUT59H
    0x00530d01, // GFXMMU_LUT60L
    0x0000b7d0, // GFXMMU_LUT60H
    0x00540d01, // GFXMMU_LUT61L
    0x0000bc40, // GFXMMU_LUT61H
    0x00540d01, // GFXMMU_LUT62L
    0x0000c0c0, // GFXMMU_LUT62H
    0x00540c01, // GFXMMU_LUT63L
    0x0000c550, // GFXMMU_LUT63H
    0x00540c01, // GFXMMU_LUT64L
    0x0000c9e0, // GFXMMU_LUT64H
    0x00550c01, // GFXMMU_LUT65L
    0x0000ce70, // GFXMMU_LUT65H
    0x00550c01, // GFXMMU_LUT66L
    0x0000d310, // GFXMMU_LUT66H
    0x00550c01, // GFXMMU_LUT67L
    0x0000d7b0, // GFXMMU_LUT67H
    0x00550b01, // GFXMMU_LUT68L
    0x0000dc60, // GFXMMU_LUT68H
    0x00550b01, // GFXMMU_LUT69L
    0x0000e110, // GFXMMU_LUT69H
    0x00560b01, // GFXMMU_LUT70L
    0x0000e5c0, // GFXMMU_LUT70H
    0x00560b01, // GFXMMU_LUT71L
    0x0000ea80, // GFXMMU_LUT71H
    0x00560a01, // GFXMMU_LUT72L
    0x0000ef50, // GFXMMU_LUT72H
    0x00560a01, // GFXMMU_LUT73L
    0x0000f420, // GFXMMU_LUT73H
    0x00560a01, // GFXMMU_LUT74L
    0x0000f8f0, // GFXMMU_LUT74H
    0x00570a01, // GFXMMU_LUT75L
    0x0000fdc0, // GFXMMU_LUT75H
    0x00570a01, // GFXMMU_LUT76L
    0x000102a0, // GFXMMU_LUT76H
    0x00570a01, // GFXMMU_LUT77L
    0x00010780, // GFXMMU_LUT77H
    0x00570901, // GFXMMU_LUT78L
    0x00010c70, // GFXMMU_LUT78H
    0x00570901, // GFXMMU_LUT79L
    0x00011160, // GFXMMU_LUT79H
    0x00580901, // GFXMMU_LUT80L
    0x00011650, // GFXMMU_LUT80H
    0x00580901, // GFXMMU_LUT81L
    0x00011b50, // GFXMMU_LUT81H
    0x00580901, // GFXMMU_LUT82L
    0x00012050, // GFXMMU_LUT82H
    0x00580801, // GFXMMU_LUT83L
    0x00012560, // GFXMMU_LUT83H
    0x00580801, // GFXMMU_LUT84L
    0x00012a70, // GFXMMU_LUT84H
    0x00580801, // GFXMMU_LUT85L
    0x00012f80, // GFXMMU_LUT85H
    0x00590801, // GFXMMU_LUT86L
    0x00013490, // GFXMMU_LUT86H
    0x00590801, // GFXMMU_LUT87L
    0x000139b0, // GFXMMU_LUT87H
    0x00590801, // GFXMMU_LUT88L
    0x00013ed0, // GFXMMU_LUT88H
    0x00590701, // GFXMMU_LUT89L
    0x00014400, // GFXMMU_LUT89H
    0x00590701, // GFXMMU_LUT90L
    0x00014930, // GFXMMU_LUT90H
    0x00590701, // GFXMMU_LUT91L
    0x00014e60, // GFXMMU_LUT91H
    0x005a0701, // GFXMMU_LUT92L
    0x00015390, // GFXMMU_LUT92H
    0x005a0701, // GFXMMU_LUT93L
    0x000158d0, // GFXMMU_LUT93H
    0x005a0701, // GFXMMU_LUT94L
    0x00015e10, // GFXMMU_LUT94H
    0x005a0601, // GFXMMU_LUT95L
    0x00016360, // GFXMMU_LUT95H
    0x005a0601, // GFXMMU_LUT96L
    0x000168b0, // GFXMMU_LUT96H
    0x005a0601, // GFXMMU_LUT97L
    0x00016e00, // GFXMMU_LUT97H
    0x005b0601, // GFXMMU_LUT98L
    0x00017350, // GFXMMU_LUT98H
    0x005b0601, // GFXMMU_LUT99L
    0x000178b0, // GFXMMU_LUT99H
    0x005b0601, // GFXMMU_LUT100L
    0x00017e10, // GFXMMU_LUT100H
    0x005b0601, // GFXMMU_LUT101L
    0x00018370, // GFXMMU_LUT101H
    0x005b0501, // GFXMMU_LUT102L
    0x000188e0, // GFXMMU_LUT102H
    0x005b0501, // GFXMMU_LUT103L
    0x00018e50, // GFXMMU_LUT103H
    0x005b0501, // GFXMMU_LUT104L
    0x000193c0, // GFXMMU_LUT104H
    0x005b0501, // GFXMMU_LUT105L
    0x00019930, // GFXMMU_LUT105H
    0x005c0501, // GFXMMU_LUT106L
    0x00019ea0, // GFXMMU_LUT106H
    0x005c0501, // GFXMMU_LUT107L
    0x0001a420, // GFXMMU_LUT107H
    0x005c0501, // GFXMMU_LUT108L
    0x0001a9a0, // GFXMMU_LUT108H
    0x005c0501, // GFXMMU_LUT109L
    0x0001af20, // GFXMMU_LUT109H
    0x005c0401, // GFXMMU_LUT110L
    0x0001b4b0, // GFXMMU_LUT110H
    0x005c0401, // GFXMMU_LUT111L
    0x0001ba40, // GFXMMU_LUT111H
    0x005c0401, // GFXMMU_LUT112L
    0x0001bfd0, // GFXMMU_LUT112H
    0x005c0401, // GFXMMU_LUT113L
    0x0001c560, // GFXMMU_LUT113H
    0x005d0401, // GFXMMU_LUT114L
    0x0001caf0, // GFXMMU_LUT114H
    0x005d0401, // GFXMMU_LUT115L
    0x0001d090, // GFXMMU_LUT115H
    0x005d0401, // GFXMMU_LUT116L
    0x0001d630, // GFXMMU_LUT116H
    0x005d0401, // GFXMMU_LUT117L
    0x0001dbd0, // GFXMMU_LUT117H
    0x005d0301, // GFXMMU_LUT118L
    0x0001e180, // GFXMMU_LUT118H
    0x005d0301, // GFXMMU_LUT119L
    0x0001e730, // GFXMMU_LUT119H
    0x005d0301, // GFXMMU_LUT120L
    0x0001ece0, // GFXMMU_LUT120H
    0x005d0301, // GFXMMU_LUT121L
    0x0001f290, // GFXMMU_LUT121H
    0x005d0301, // GFXMMU_LUT122L
    0x0001f840, // GFXMMU_LUT122H
    0x005e0301, // GFXMMU_LUT123L
    0x0001fdf0, // GFXMMU_LUT123H
    0x005e0301, // GFXMMU_LUT124L
    0x000203b0, // GFXMMU_LUT124H
    0x005e0301, // GFXMMU_LUT125L
    0x00020970, // GFXMMU_LUT125H
    0x005e0301, // GFXMMU_LUT126L
    0x00020f30, // GFXMMU_LUT126H
    0x005e0301, // GFXMMU_LUT127L
    0x000214f0, // GFXMMU_LUT127H
    0x005e0301, // GFXMMU_LUT128L
    0x00021ab0, // GFXMMU_LUT128H
    0x005e0201, // GFXMMU_LUT129L
    0x00022080, // GFXMMU_LUT129H
    0x005e0201, // GFXMMU_LUT130L
    0x00022650, // GFXMMU_LUT130H
    0x005e0201, // GFXMMU_LUT131L
    0x00022c20, // GFXMMU_LUT131H
    0x005e0201, // GFXMMU_LUT132L
    0x000231f0, // GFXMMU_LUT132H
    0x005e0201, // GFXMMU_LUT133L
    0x000237c0, // GFXMMU_LUT133H
    0x005e0201, // GFXMMU_LUT134L
    0x00023d90, // GFXMMU_LUT134H
    0x005f0201, // GFXMMU_LUT135L
    0x00024360, // GFXMMU_LUT135H
    0x005f0201, // GFXMMU_LUT136L
    0x00024940, // GFXMMU_LUT136H
    0x005f0201, // GFXMMU_LUT137L
    0x00024f20, // GFXMMU_LUT137H
    0x005f0201, // GFXMMU_LUT138L
    0x00025500, // GFXMMU_LUT138H
    0x005f0201, // GFXMMU_LUT139L
    0x00025ae0, // GFXMMU_LUT139H
    0x005f0201, // GFXMMU_LUT140L
    0x000260c0, // GFXMMU_LUT140H
    0x005f0101, // GFXMMU_LUT141L
    0x000266b0, // GFXMMU_LUT141H
    0x005f0101, // GFXMMU_LUT142L
    0x00026ca0, // GFXMMU_LUT142H
    0x005f0101, // GFXMMU_LUT143L
    0x00027290, // GFXMMU_LUT143H
    0x005f0101, // GFXMMU_LUT144L
    0x00027880, // GFXMMU_LUT144H
    0x005f0101, // GFXMMU_LUT145L
    0x00027e70, // GFXMMU_LUT145H
    0x005f0101, // GFXMMU_LUT146L
    0x00028460, // GFXMMU_LUT146H
    0x005f0101, // GFXMMU_LUT147L
    0x00028a50, // GFXMMU_LUT147H
    0x005f0101, // GFXMMU_LUT148L
    0x00029040, // GFXMMU_LUT148H
    0x00600101, // GFXMMU_LUT149L
    0x00029630, // GFXMMU_LUT149H
    0x00600101, // GFXMMU_LUT150L
    0x00029c30, // GFXMMU_LUT150H
    0x00600101, // GFXMMU_LUT151L
    0x0002a230, // GFXMMU_LUT151H
    0x00600101, // GFXMMU_LUT152L
    0x0002a830, // GFXMMU_LUT152H
    0x00600101, // GFXMMU_LUT153L
    0x0002ae30, // GFXMMU_LUT153H
    0x00600101, // GFXMMU_LUT154L
    0x0002b430, // GFXMMU_LUT154H
    0x00600101, // GFXMMU_LUT155L
    0x0002ba30, // GFXMMU_LUT155H
    0x00600101, // GFXMMU_LUT156L
    0x0002c030, // GFXMMU_LUT156H
    0x00600101, // GFXMMU_LUT157L
    0x0002c630, // GFXMMU_LUT157H
    0x00600001, // GFXMMU_LUT158L
    0x0002cc40, // GFXMMU_LUT158H
    0x00600001, // GFXMMU_LUT159L
    0x0002d250, // GFXMMU_LUT159H
    0x00600001, // GFXMMU_LUT160L
    0x0002d860, // GFXMMU_LUT160H
    0x00600001, // GFXMMU_LUT161L
    0x0002de70, // GFXMMU_LUT161H
    0x00600001, // GFXMMU_LUT162L
    0x0002e480, // GFXMMU_LUT162H
    0x00600001, // GFXMMU_LUT163L
    0x0002ea90, // GFXMMU_LUT163H
    0x00600001, // GFXMMU_LUT164L
    0x0002f0a0, // GFXMMU_LUT164H
    0x00600001, // GFXMMU_LUT165L
    0x0002f6b0, // GFXMMU_LUT165H
    0x00600001, // GFXMMU_LUT166L
    0x0002fcc0, // GFXMMU_LUT166H
    0x00600001, // GFXMMU_LUT167L
    0x000302d0, // GFXMMU_LUT167H
    0x00600001, // GFXMMU_LUT168L
    0x000308e0, // GFXMMU_LUT168H
    0x00600001, // GFXMMU_LUT169L
    0x00030ef0, // GFXMMU_LUT169H
    0x00600001, // GFXMMU_LUT170L
    0x00031500, // GFXMMU_LUT170H
    0x00610001, // GFXMMU_LUT171L
    0x00031b10, // GFXMMU_LUT171H
    0x00610001, // GFXMMU_LUT172L
    0x00032130, // GFXMMU_LUT172H
    0x00610001, // GFXMMU_LUT173L
    0x00032750, // GFXMMU_LUT173H
    0x00610001, // GFXMMU_LUT174L
    0x00032d70, // GFXMMU_LUT174H
    0x00610001, // GFXMMU_LUT175L
    0x00033390, // GFXMMU_LUT175H
    0x00610001, // GFXMMU_LUT176L
    0x000339b0, // GFXMMU_LUT176H
    0x00610001, // GFXMMU_LUT177L
    0x00033fd0, // GFXMMU_LUT177H
    0x00610001, // GFXMMU_LUT178L
    0x000345f0, // GFXMMU_LUT178H
    0x00610001, // GFXMMU_LUT179L
    0x00034c10, // GFXMMU_LUT179H
    0x00610001, // GFXMMU_LUT180L
    0x00035230, // GFXMMU_LUT180H
    0x00610001, // GFXMMU_LUT181L
    0x00035850, // GFXMMU_LUT181H
    0x00610001, // GFXMMU_LUT182L
    0x00035e70, // GFXMMU_LUT182H
    0x00610001, // GFXMMU_LUT183L
    0x00036490, // GFXMMU_LUT183H
    0x00610001, // GFXMMU_LUT184L
    0x00036ab0, // GFXMMU_LUT184H
    0x00610001, // GFXMMU_LUT185L
    0x000370d0, // GFXMMU_LUT185H
    0x00610001, // GFXMMU_LUT186L
    0x000376f0, // GFXMMU_LUT186H
    0x00610001, // GFXMMU_LUT187L
    0x00037d10, // GFXMMU_LUT187H
    0x00610001, // GFXMMU_LUT188L
    0x00038330, // GFXMMU_LUT188H
    0x00610001, // GFXMMU_LUT189L
    0x00038950, // GFXMMU_LUT189H
    0x00610001, // GFXMMU_LUT190L
    0x00038f70, // GFXMMU_LUT190H
    0x00610001, // GFXMMU_LUT191L
    0x00039590, // GFXMMU_LUT191H
    0x00610001, // GFXMMU_LUT192L
    0x00039bb0, // GFXMMU_LUT192H
    0x00610001, // GFXMMU_LUT193L
    0x0003a1d0, // GFXMMU_LUT193H
    0x00610001, // GFXMMU_LUT194L
    0x0003a7f0, // GFXMMU_LUT194H
    0x00610001, // GFXMMU_LUT195L
    0x0003ae10, // GFXMMU_LUT195H
    0x00610001, // GFXMMU_LUT196L
    0x0003b430, // GFXMMU_LUT196H
    0x00610001, // GFXMMU_LUT197L
    0x0003ba50, // GFXMMU_LUT197H
    0x00610001, // GFXMMU_LUT198L
    0x0003c070, // GFXMMU_LUT198H
    0x00610001, // GFXMMU_LUT199L
    0x0003c690, // GFXMMU_LUT199H
    0x00610001, // GFXMMU_LUT200L
    0x0003ccb0, // GFXMMU_LUT200H
    0x00610001, // GFXMMU_LUT201L
    0x0003d2d0, // GFXMMU_LUT201H
    0x00610001, // GFXMMU_LUT202L
    0x0003d8f0, // GFXMMU_LUT202H
    0x00610001, // GFXMMU_LUT203L
    0x0003df10, // GFXMMU_LUT203H
    0x00610001, // GFXMMU_LUT204L
    0x0003e530, // GFXMMU_LUT204H
    0x00610001, // GFXMMU_LUT205L
    0x0003eb50, // GFXMMU_LUT205H
    0x00610001, // GFXMMU_LUT206L
    0x0003f170, // GFXMMU_LUT206H
    0x00610001, // GFXMMU_LUT207L
    0x0003f790, // GFXMMU_LUT207H
    0x00610001, // GFXMMU_LUT208L
    0x0003fdb0, // GFXMMU_LUT208H
    0x00610001, // GFXMMU_LUT209L
    0x000403d0, // GFXMMU_LUT209H
    0x00610001, // GFXMMU_LUT210L
    0x000409f0, // GFXMMU_LUT210H
    0x00610001, // GFXMMU_LUT211L
    0x00041010, // GFXMMU_LUT211H
    0x00610001, // GFXMMU_LUT212L
    0x00041630, // GFXMMU_LUT212H
    0x00610001, // GFXMMU_LUT213L
    0x00041c50, // GFXMMU_LUT213H
    0x00610001, // GFXMMU_LUT214L
    0x00042270, // GFXMMU_LUT214H
    0x00610001, // GFXMMU_LUT215L
    0x00042890, // GFXMMU_LUT215H
    0x00610001, // GFXMMU_LUT216L
    0x00042eb0, // GFXMMU_LUT216H
    0x00610001, // GFXMMU_LUT217L
    0x000434d0, // GFXMMU_LUT217H
    0x00610001, // GFXMMU_LUT218L
    0x00043af0, // GFXMMU_LUT218H
    0x00600001, // GFXMMU_LUT219L
    0x00044110, // GFXMMU_LUT219H
    0x00600001, // GFXMMU_LUT220L
    0x00044720, // GFXMMU_LUT220H
    0x00600001, // GFXMMU_LUT221L
    0x00044d30, // GFXMMU_LUT221H
    0x00600001, // GFXMMU_LUT222L
    0x00045340, // GFXMMU_LUT222H
    0x00600001, // GFXMMU_LUT223L
    0x00045950, // GFXMMU_LUT223H
    0x00600001, // GFXMMU_LUT224L
    0x00045f60, // GFXMMU_LUT224H
    0x00600001, // GFXMMU_LUT225L
    0x00046570, // GFXMMU_LUT225H
    0x00600001, // GFXMMU_LUT226L
    0x00046b80, // GFXMMU_LUT226H
    0x00600001, // GFXMMU_LUT227L
    0x00047190, // GFXMMU_LUT227H
    0x00600001, // GFXMMU_LUT228L
    0x000477a0, // GFXMMU_LUT228H
    0x00600001, // GFXMMU_LUT229L
    0x00047db0, // GFXMMU_LUT229H
    0x00600001, // GFXMMU_LUT230L
    0x000483c0, // GFXMMU_LUT230H
    0x00600001, // GFXMMU_LUT231L
    0x000489d0, // GFXMMU_LUT231H
    0x00600101, // GFXMMU_LUT232L
    0x00048fd0, // GFXMMU_LUT232H
    0x00600101, // GFXMMU_LUT233L
    0x000495d0, // GFXMMU_LUT233H
    0x00600101, // GFXMMU_LUT234L
    0x00049bd0, // GFXMMU_LUT234H
    0x00600101, // GFXMMU_LUT235L
    0x0004a1d0, // GFXMMU_LUT235H
    0x00600101, // GFXMMU_LUT236L
    0x0004a7d0, // GFXMMU_LUT236H
    0x00600101, // GFXMMU_LUT237L
    0x0004add0, // GFXMMU_LUT237H
    0x00600101, // GFXMMU_LUT238L
    0x0004b3d0, // GFXMMU_LUT238H
    0x00600101, // GFXMMU_LUT239L
    0x0004b9d0, // GFXMMU_LUT239H
    0x00600101, // GFXMMU_LUT240L
    0x0004bfd0, // GFXMMU_LUT240H
    0x005f0101, // GFXMMU_LUT241L
    0x0004c5d0, // GFXMMU_LUT241H
    0x005f0101, // GFXMMU_LUT242L
    0x0004cbc0, // GFXMMU_LUT242H
    0x005f0101, // GFXMMU_LUT243L
    0x0004d1b0, // GFXMMU_LUT243H
    0x005f0101, // GFXMMU_LUT244L
    0x0004d7a0, // GFXMMU_LUT244H
    0x005f0101, // GFXMMU_LUT245L
    0x0004dd90, // GFXMMU_LUT245H
    0x005f0101, // GFXMMU_LUT246L
    0x0004e380, // GFXMMU_LUT246H
    0x005f0101, // GFXMMU_LUT247L
    0x0004e970, // GFXMMU_LUT247H
    0x005f0101, // GFXMMU_LUT248L
    0x0004ef60, // GFXMMU_LUT248H
    0x005f0201, // GFXMMU_LUT249L
    0x0004f540, // GFXMMU_LUT249H
    0x005f0201, // GFXMMU_LUT250L
    0x0004fb20, // GFXMMU_LUT250H
    0x005f0201, // GFXMMU_LUT251L
    0x00050100, // GFXMMU_LUT251H
    0x005f0201, // GFXMMU_LUT252L
    0x000506e0, // GFXMMU_LUT252H
    0x005f0201, // GFXMMU_LUT253L
    0x00050cc0, // GFXMMU_LUT253H
    0x005f0201, // GFXMMU_LUT254L
    0x000512a0, // GFXMMU_LUT254H
    0x005e0201, // GFXMMU_LUT255L
    0x00051880, // GFXMMU_LUT255H
    0x005e0201, // GFXMMU_LUT256L
    0x00051e50, // GFXMMU_LUT256H
    0x005e0201, // GFXMMU_LUT257L
    0x00052420, // GFXMMU_LUT257H
    0x005e0201, // GFXMMU_LUT258L
    0x000529f0, // GFXMMU_LUT258H
    0x005e0201, // GFXMMU_LUT259L
    0x00052fc0, // GFXMMU_LUT259H
    0x005e0201, // GFXMMU_LUT260L
    0x00053590, // GFXMMU_LUT260H
    0x005e0301, // GFXMMU_LUT261L
    0x00053b50, // GFXMMU_LUT261H
    0x005e0301, // GFXMMU_LUT262L
    0x00054110, // GFXMMU_LUT262H
    0x005e0301, // GFXMMU_LUT263L
    0x000546d0, // GFXMMU_LUT263H
    0x005e0301, // GFXMMU_LUT264L
    0x00054c90, // GFXMMU_LUT264H
    0x005e0301, // GFXMMU_LUT265L
    0x00055250, // GFXMMU_LUT265H
    0x005e0301, // GFXMMU_LUT266L
    0x00055810, // GFXMMU_LUT266H
    0x005d0301, // GFXMMU_LUT267L
    0x00055dd0, // GFXMMU_LUT267H
    0x005d0301, // GFXMMU_LUT268L
    0x00056380, // GFXMMU_LUT268H
    0x005d0301, // GFXMMU_LUT269L
    0x00056930, // GFXMMU_LUT269H
    0x005d0301, // GFXMMU_LUT270L
    0x00056ee0, // GFXMMU_LUT270H
    0x005d0301, // GFXMMU_LUT271L
    0x00057490, // GFXMMU_LUT271H
    0x005d0401, // GFXMMU_LUT272L
    0x00057a30, // GFXMMU_LUT272H
    0x005d0401, // GFXMMU_LUT273L
    0x00057fd0, // GFXMMU_LUT273H
    0x005d0401, // GFXMMU_LUT274L
    0x00058570, // GFXMMU_LUT274H
    0x005d0401, // GFXMMU_LUT275L
    0x00058b10, // GFXMMU_LUT275H
    0x005c0401, // GFXMMU_LUT276L
    0x000590b0, // GFXMMU_LUT276H
    0x005c0401, // GFXMMU_LUT277L
    0x00059640, // GFXMMU_LUT277H
    0x005c0401, // GFXMMU_LUT278L
    0x00059bd0, // GFXMMU_LUT278H
    0x005c0401, // GFXMMU_LUT279L
    0x0005a160, // GFXMMU_LUT279H
    0x005c0501, // GFXMMU_LUT280L
    0x0005a6e0, // GFXMMU_LUT280H
    0x005c0501, // GFXMMU_LUT281L
    0x0005ac60, // GFXMMU_LUT281H
    0x005c0501, // GFXMMU_LUT282L
    0x0005b1e0, // GFXMMU_LUT282H
    0x005c0501, // GFXMMU_LUT283L
    0x0005b760, // GFXMMU_LUT283H
    0x005b0501, // GFXMMU_LUT284L
    0x0005bce0, // GFXMMU_LUT284H
    0x005b0501, // GFXMMU_LUT285L
    0x0005c250, // GFXMMU_LUT285H
    0x005b0501, // GFXMMU_LUT286L
    0x0005c7c0, // GFXMMU_LUT286H
    0x005b0501, // GFXMMU_LUT287L
    0x0005cd30, // GFXMMU_LUT287H
    0x005b0601, // GFXMMU_LUT288L
    0x0005d290, // GFXMMU_LUT288H
    0x005b0601, // GFXMMU_LUT289L
    0x0005d7f0, // GFXMMU_LUT289H
    0x005b0601, // GFXMMU_LUT290L
    0x0005dd50, // GFXMMU_LUT290H
    0x005b0601, // GFXMMU_LUT291L
    0x0005e2b0, // GFXMMU_LUT291H
    0x005a0601, // GFXMMU_LUT292L
    0x0005e810, // GFXMMU_LUT292H
    0x005a0601, // GFXMMU_LUT293L
    0x0005ed60, // GFXMMU_LUT293H
    0x005a0601, // GFXMMU_LUT294L
    0x0005f2b0, // GFXMMU_LUT294H
    0x005a0701, // GFXMMU_LUT295L
    0x0005f7f0, // GFXMMU_LUT295H
    0x005a0701, // GFXMMU_LUT296L
    0x0005fd30, // GFXMMU_LUT296H
    0x005a0701, // GFXMMU_LUT297L
    0x00060270, // GFXMMU_LUT297H
    0x00590701, // GFXMMU_LUT298L
    0x000607b0, // GFXMMU_LUT298H
    0x00590701, // GFXMMU_LUT299L
    0x00060ce0, // GFXMMU_LUT299H
    0x00590701, // GFXMMU_LUT300L
    0x00061210, // GFXMMU_LUT300H
    0x00590801, // GFXMMU_LUT301L
    0x00061730, // GFXMMU_LUT301H
    0x00590801, // GFXMMU_LUT302L
    0x00061c50, // GFXMMU_LUT302H
    0x00590801, // GFXMMU_LUT303L
    0x00062170, // GFXMMU_LUT303H
    0x00580801, // GFXMMU_LUT304L
    0x00062690, // GFXMMU_LUT304H
    0x00580801, // GFXMMU_LUT305L
    0x00062ba0, // GFXMMU_LUT305H
    0x00580801, // GFXMMU_LUT306L
    0x000630b0, // GFXMMU_LUT306H
    0x00580901, // GFXMMU_LUT307L
    0x000635b0, // GFXMMU_LUT307H
    0x00580901, // GFXMMU_LUT308L
    0x00063ab0, // GFXMMU_LUT308H
    0x00580901, // GFXMMU_LUT309L
    0x00063fb0, // GFXMMU_LUT309H
    0x00570901, // GFXMMU_LUT310L
    0x000644b0, // GFXMMU_LUT310H
    0x00570901, // GFXMMU_LUT311L
    0x000649a0, // GFXMMU_LUT311H
    0x00570a01, // GFXMMU_LUT312L
    0x00064e80, // GFXMMU_LUT312H
    0x00570a01, // GFXMMU_LUT313L
    0x00065360, // GFXMMU_LUT313H
    0x00570a01, // GFXMMU_LUT314L
    0x00065840, // GFXMMU_LUT314H
    0x00560a01, // GFXMMU_LUT315L
    0x00065d20, // GFXMMU_LUT315H
    0x00560a01, // GFXMMU_LUT316L
    0x000661f0, // GFXMMU_LUT316H
    0x00560a01, // GFXMMU_LUT317L
    0x000666c0, // GFXMMU_LUT317H
    0x00560b01, // GFXMMU_LUT318L
    0x00066b80, // GFXMMU_LUT318H
    0x00560b01, // GFXMMU_LUT319L
    0x00067040, // GFXMMU_LUT319H
    0x00550b01, // GFXMMU_LUT320L
    0x00067500, // GFXMMU_LUT320H
    0x00550b01, // GFXMMU_LUT321L
    0x000679b0, // GFXMMU_LUT321H
    0x00550c01, // GFXMMU_LUT322L
    0x00067e50, // GFXMMU_LUT322H
    0x00550c01, // GFXMMU_LUT323L
    0x000682f0, // GFXMMU_LUT323H
    0x00550c01, // GFXMMU_LUT324L
    0x00068790, // GFXMMU_LUT324H
    0x00540c01, // GFXMMU_LUT325L
    0x00068c30, // GFXMMU_LUT325H
    0x00540c01, // GFXMMU_LUT326L
    0x000690c0, // GFXMMU_LUT326H
    0x00540d01, // GFXMMU_LUT327L
    0x00069540, // GFXMMU_LUT327H
    0x00540d01, // GFXMMU_LUT328L
    0x000699c0, // GFXMMU_LUT328H
    0x00530d01, // GFXMMU_LUT329L
    0x00069e40, // GFXMMU_LUT329H
    0x00530d01, // GFXMMU_LUT330L
    0x0006a2b0, // GFXMMU_LUT330H
    0x00530e01, // GFXMMU_LUT331L
    0x0006a710, // GFXMMU_LUT331H
    0x00530e01, // GFXMMU_LUT332L
    0x0006ab70, // GFXMMU_LUT332H
    0x00520e01, // GFXMMU_LUT333L
    0x0006afd0, // GFXMMU_LUT333H
    0x00520e01, // GFXMMU_LUT334L
    0x0006b420, // GFXMMU_LUT334H
    0x00520f01, // GFXMMU_LUT335L
    0x0006b860, // GFXMMU_LUT335H
    0x00520f01, // GFXMMU_LUT336L
    0x0006bca0, // GFXMMU_LUT336H
    0x00510f01, // GFXMMU_LUT337L
    0x0006c0e0, // GFXMMU_LUT337H
    0x00510f01, // GFXMMU_LUT338L
    0x0006c510, // GFXMMU_LUT338H
    0x00511001, // GFXMMU_LUT339L
    0x0006c930, // GFXMMU_LUT339H
    0x00511001, // GFXMMU_LUT340L
    0x0006cd50, // GFXMMU_LUT340H
    0x00501001, // GFXMMU_LUT341L
    0x0006d170, // GFXMMU_LUT341H
    0x00501101, // GFXMMU_LUT342L
    0x0006d570, // GFXMMU_LUT342H
    0x00501101, // GFXMMU_LUT343L
    0x0006d970, // GFXMMU_LUT343H
    0x004f1101, // GFXMMU_LUT344L
    0x0006dd70, // GFXMMU_LUT344H
    0x004f1101, // GFXMMU_LUT345L
    0x0006e160, // GFXMMU_LUT345H
    0x004f1201, // GFXMMU_LUT346L
    0x0006e540, // GFXMMU_LUT346H
    0x004e1201, // GFXMMU_LUT347L
    0x0006e920, // GFXMMU_LUT347H
    0x004e1201, // GFXMMU_LUT348L
    0x0006ecf0, // GFXMMU_LUT348H
    0x004e1301, // GFXMMU_LUT349L
    0x0006f0b0, // GFXMMU_LUT349H
    0x004e1301, // GFXMMU_LUT350L
    0x0006f470, // GFXMMU_LUT350H
    0x004d1301, // GFXMMU_LUT351L
    0x0006f830, // GFXMMU_LUT351H
    0x004d1401, // GFXMMU_LUT352L
    0x0006fbd0, // GFXMMU_LUT352H
    0x004c1401, // GFXMMU_LUT353L
    0x0006ff70, // GFXMMU_LUT353H
    0x004c1401, // GFXMMU_LUT354L
    0x00070300, // GFXMMU_LUT354H
    0x004c1501, // GFXMMU_LUT355L
    0x00070680, // GFXMMU_LUT355H
    0x004b1501, // GFXMMU_LUT356L
    0x00070a00, // GFXMMU_LUT356H
    0x004b1501, // GFXMMU_LUT357L
    0x00070d70, // GFXMMU_LUT357H
    0x004b1601, // GFXMMU_LUT358L
    0x000710d0, // GFXMMU_LUT358H
    0x004a1601, // GFXMMU_LUT359L
    0x00071430, // GFXMMU_LUT359H
    0x004a1701, // GFXMMU_LUT360L
    0x00071770, // GFXMMU_LUT360H
    0x00491701, // GFXMMU_LUT361L
    0x00071ab0, // GFXMMU_LUT361H
    0x00491701, // GFXMMU_LUT362L
    0x00071de0, // GFXMMU_LUT362H
    0x00491801, // GFXMMU_LUT363L
    0x00072100, // GFXMMU_LUT363H
    0x00481801, // GFXMMU_LUT364L
    0x00072420, // GFXMMU_LUT364H
    0x00481901, // GFXMMU_LUT365L
    0x00072720, // GFXMMU_LUT365H
    0x00471901, // GFXMMU_LUT366L
    0x00072a20, // GFXMMU_LUT366H
    0x00471a01, // GFXMMU_LUT367L
    0x00072d00, // GFXMMU_LUT367H
    0x00461a01, // GFXMMU_LUT368L
    0x00072fe0, // GFXMMU_LUT368H
    0x00461b01, // GFXMMU_LUT369L
    0x000732a0, // GFXMMU_LUT369H
    0x00451b01, // GFXMMU_LUT370L
    0x00073560, // GFXMMU_LUT370H
    0x00451c01, // GFXMMU_LUT371L
    0x00073800, // GFXMMU_LUT371H
    0x00441c01, // GFXMMU_LUT372L
    0x00073aa0, // GFXMMU_LUT372H
    0x00441d01, // GFXMMU_LUT373L
    0x00073d20, // GFXMMU_LUT373H
    0x00431d01, // GFXMMU_LUT374L
    0x00073fa0, // GFXMMU_LUT374H
    0x00431e01, // GFXMMU_LUT375L
    0x00074200, // GFXMMU_LUT375H
    0x00421f01, // GFXMMU_LUT376L
    0x00074450, // GFXMMU_LUT376H
    0x00411f01, // GFXMMU_LUT377L
    0x00074690, // GFXMMU_LUT377H
    0x00402001, // GFXMMU_LUT378L
    0x000748b0, // GFXMMU_LUT378H
    0x00402101, // GFXMMU_LUT379L
    0x00074ab0, // GFXMMU_LUT379H
    0x003f2101, // GFXMMU_LUT380L
    0x00074cb0, // GFXMMU_LUT380H
    0x003e2201, // GFXMMU_LUT381L
    0x00074e90, // GFXMMU_LUT381H
    0x003d2301, // GFXMMU_LUT382L
    0x00075050, // GFXMMU_LUT382H
    0x003d2401, // GFXMMU_LUT383L
    0x000751f0, // GFXMMU_LUT383H
    0x003c2501, // GFXMMU_LUT384L
    0x00075380, // GFXMMU_LUT384H
    0x003b2601, // GFXMMU_LUT385L
    0x000754f0, // GFXMMU_LUT385H
    0x00392701, // GFXMMU_LUT386L
    0x00075640, // GFXMMU_LUT386H
    0x00382901, // GFXMMU_LUT387L
    0x00075750, // GFXMMU_LUT387H
    0x00362b01, // GFXMMU_LUT388L
    0x00075830, // GFXMMU_LUT388H
    0x00342d01, // GFXMMU_LUT389L
    0x000758d0  // GFXMMU_LUT389H
};

#elif (( EW_FRAME_BUFFER_COLOR_FORMAT == EW_FRAME_BUFFER_COLOR_FORMAT_Index8 ) || ( EW_FRAME_BUFFER_COLOR_FORMAT == EW_FRAME_BUFFER_COLOR_FORMAT_LumA44 ))
static const uint32_t gfxmmu_lut_config[GFXMMU_LUT_SIZE] = {
    0x000D0B01, 0x003FFF50,
    0x000D0A01, 0x003FFF90,
    0x000E0A01, 0x003FFFD0,
    0x000E0901, 0x00000030,
    0x000E0901, 0x00000090,
    0x000F0901, 0x000000F0,
    0x000F0901, 0x00000160,
    0x000F0801, 0x000001E0,
    0x000F0801, 0x00000260,
    0x000F0801, 0x000002E0,
    0x00100801, 0x00000360,
    0x00100801, 0x000003F0,
    0x00100701, 0x00000490,
    0x00100701, 0x00000530,
    0x00100701, 0x000005D0,
    0x00100701, 0x00000670,
    0x00110701, 0x00000710,
    0x00110701, 0x000007C0,
    0x00110701, 0x00000870,
    0x00110601, 0x00000930,
    0x00110601, 0x000009F0,
    0x00110601, 0x00000AB0,
    0x00110601, 0x00000B70,
    0x00110601, 0x00000C30,
    0x00120601, 0x00000CF0,
    0x00120601, 0x00000DC0,
    0x00120601, 0x00000E90,
    0x00120501, 0x00000F70,
    0x00120501, 0x00001050,
    0x00120501, 0x00001130,
    0x00120501, 0x00001210,
    0x00120501, 0x000012F0,
    0x00120501, 0x000013D0,
    0x00120501, 0x000014B0,
    0x00130501, 0x00001590,
    0x00130501, 0x00001680,
    0x00130501, 0x00001770,
    0x00130501, 0x00001860,
    0x00130401, 0x00001960,
    0x00130401, 0x00001A60,
    0x00130401, 0x00001B60,
    0x00130401, 0x00001C60,
    0x00130401, 0x00001D60,
    0x00130401, 0x00001E60,
    0x00130401, 0x00001F60,
    0x00130401, 0x00002060,
    0x00140401, 0x00002160,
    0x00140401, 0x00002270,
    0x00140401, 0x00002380,
    0x00140401, 0x00002490,
    0x00140401, 0x000025A0,
    0x00140301, 0x000026C0,
    0x00140301, 0x000027E0,
    0x00140301, 0x00002900,
    0x00140301, 0x00002A20,
    0x00140301, 0x00002B40,
    0x00140301, 0x00002C60,
    0x00140301, 0x00002D80,
    0x00140301, 0x00002EA0,
    0x00140301, 0x00002FC0,
    0x00140301, 0x000030E0,
    0x00150301, 0x00003200,
    0x00150301, 0x00003330,
    0x00150301, 0x00003460,
    0x00150301, 0x00003590,
    0x00150301, 0x000036C0,
    0x00150301, 0x000037F0,
    0x00150301, 0x00003920,
    0x00150201, 0x00003A60,
    0x00150201, 0x00003BA0,
    0x00150201, 0x00003CE0,
    0x00150201, 0x00003E20,
    0x00150201, 0x00003F60,
    0x00150201, 0x000040A0,
    0x00150201, 0x000041E0,
    0x00150201, 0x00004320,
    0x00150201, 0x00004460,
    0x00150201, 0x000045A0,
    0x00150201, 0x000046E0,
    0x00150201, 0x00004820,
    0x00160201, 0x00004960,
    0x00160201, 0x00004AB0,
    0x00160201, 0x00004C00,
    0x00160201, 0x00004D50,
    0x00160201, 0x00004EA0,
    0x00160201, 0x00004FF0,
    0x00160201, 0x00005140,
    0x00160201, 0x00005290,
    0x00160201, 0x000053E0,
    0x00160101, 0x00005540,
    0x00160101, 0x000056A0,
    0x00160101, 0x00005800,
    0x00160101, 0x00005960,
    0x00160101, 0x00005AC0,
    0x00160101, 0x00005C20,
    0x00160101, 0x00005D80,
    0x00160101, 0x00005EE0,
    0x00160101, 0x00006040,
    0x00160101, 0x000061A0,
    0x00160101, 0x00006300,
    0x00160101, 0x00006460,
    0x00160101, 0x000065C0,
    0x00160101, 0x00006720,
    0x00160101, 0x00006880,
    0x00160101, 0x000069E0,
    0x00160101, 0x00006B40,
    0x00170101, 0x00006CA0,
    0x00170101, 0x00006E10,
    0x00170101, 0x00006F80,
    0x00170101, 0x000070F0,
    0x00170101, 0x00007260,
    0x00170101, 0x000073D0,
    0x00170101, 0x00007540,
    0x00170101, 0x000076B0,
    0x00170101, 0x00007820,
    0x00170101, 0x00007990,
    0x00170101, 0x00007B00,
    0x00170101, 0x00007C70,
    0x00170001, 0x00007DF0,
    0x00170001, 0x00007F70,
    0x00170001, 0x000080F0,
    0x00170001, 0x00008270,
    0x00170001, 0x000083F0,
    0x00170001, 0x00008570,
    0x00170001, 0x000086F0,
    0x00170001, 0x00008870,
    0x00170001, 0x000089F0,
    0x00170001, 0x00008B70,
    0x00170001, 0x00008CF0,
    0x00170001, 0x00008E70,
    0x00170001, 0x00008FF0,
    0x00170001, 0x00009170,
    0x00170001, 0x000092F0,
    0x00170001, 0x00009470,
    0x00170001, 0x000095F0,
    0x00170001, 0x00009770,
    0x00170001, 0x000098F0,
    0x00170001, 0x00009A70,
    0x00170001, 0x00009BF0,
    0x00170001, 0x00009D70,
    0x00170001, 0x00009EF0,
    0x00170001, 0x0000A070,
    0x00170001, 0x0000A1F0,
    0x00170001, 0x0000A370,
    0x00170001, 0x0000A4F0,
    0x00170001, 0x0000A670,
    0x00170001, 0x0000A7F0,
    0x00170001, 0x0000A970,
    0x00170001, 0x0000AAF0,
    0x00180001, 0x0000AC70,
    0x00180001, 0x0000AE00,
    0x00180001, 0x0000AF90,
    0x00180001, 0x0000B120,
    0x00180001, 0x0000B2B0,
    0x00180001, 0x0000B440,
    0x00180001, 0x0000B5D0,
    0x00180001, 0x0000B760,
    0x00180001, 0x0000B8F0,
    0x00180001, 0x0000BA80,
    0x00180001, 0x0000BC10,
    0x00180001, 0x0000BDA0,
    0x00180001, 0x0000BF30,
    0x00180001, 0x0000C0C0,
    0x00180001, 0x0000C250,
    0x00180001, 0x0000C3E0,
    0x00180001, 0x0000C570,
    0x00180001, 0x0000C700,
    0x00180001, 0x0000C890,
    0x00180001, 0x0000CA20,
    0x00180001, 0x0000CBB0,
    0x00180001, 0x0000CD40,
    0x00180001, 0x0000CED0,
    0x00180001, 0x0000D060,
    0x00180001, 0x0000D1F0,
    0x00180001, 0x0000D380,
    0x00180001, 0x0000D510,
    0x00180001, 0x0000D6A0,
    0x00180001, 0x0000D830,
    0x00180001, 0x0000D9C0,
    0x00180001, 0x0000DB50,
    0x00180001, 0x0000DCE0,
    0x00180001, 0x0000DE70,
    0x00180001, 0x0000E000,
    0x00180001, 0x0000E190,
    0x00180001, 0x0000E320,
    0x00180001, 0x0000E4B0,
    0x00180001, 0x0000E640,
    0x00180001, 0x0000E7D0,
    0x00180001, 0x0000E960,
    0x00180001, 0x0000EAF0,
    0x00180001, 0x0000EC80,
    0x00180001, 0x0000EE10,
    0x00180001, 0x0000EFA0,
    0x00180001, 0x0000F130,
    0x00180001, 0x0000F2C0,
    0x00180001, 0x0000F450,
    0x00180001, 0x0000F5E0,
    0x00180001, 0x0000F770,
    0x00180001, 0x0000F900,
    0x00180001, 0x0000FA90,
    0x00180001, 0x0000FC20,
    0x00180001, 0x0000FDB0,
    0x00180001, 0x0000FF40,
    0x00180001, 0x000100D0,
    0x00180001, 0x00010260,
    0x00180001, 0x000103F0,
    0x00180001, 0x00010580,
    0x00180001, 0x00010710,
    0x00180001, 0x000108A0,
    0x00180001, 0x00010A30,
    0x00180001, 0x00010BC0,
    0x00180001, 0x00010D50,
    0x00180001, 0x00010EE0,
    0x00180001, 0x00011070,
    0x00180001, 0x00011200,
    0x00180001, 0x00011390,
    0x00180001, 0x00011520,
    0x00180001, 0x000116B0,
    0x00180001, 0x00011840,
    0x00180001, 0x000119D0,
    0x00180001, 0x00011B60,
    0x00180001, 0x00011CF0,
    0x00180001, 0x00011E80,
    0x00180001, 0x00012010,
    0x00180001, 0x000121A0,
    0x00180001, 0x00012330,
    0x00180001, 0x000124C0,
    0x00180001, 0x00012650,
    0x00180001, 0x000127E0,
    0x00180001, 0x00012970,
    0x00180001, 0x00012B00,
    0x00180001, 0x00012C90,
    0x00180001, 0x00012E20,
    0x00180001, 0x00012FB0,
    0x00180001, 0x00013140,
    0x00180001, 0x000132D0,
    0x00180001, 0x00013460,
    0x00180001, 0x000135F0,
    0x00180001, 0x00013780,
    0x00180001, 0x00013910,
    0x00180001, 0x00013AA0,
    0x00170001, 0x00013C30,
    0x00170001, 0x00013DB0,
    0x00170001, 0x00013F30,
    0x00170001, 0x000140B0,
    0x00170001, 0x00014230,
    0x00170001, 0x000143B0,
    0x00170001, 0x00014530,
    0x00170001, 0x000146B0,
    0x00170001, 0x00014830,
    0x00170001, 0x000149B0,
    0x00170001, 0x00014B30,
    0x00170001, 0x00014CB0,
    0x00170001, 0x00014E30,
    0x00170001, 0x00014FB0,
    0x00170001, 0x00015130,
    0x00170001, 0x000152B0,
    0x00170001, 0x00015430,
    0x00170001, 0x000155B0,
    0x00170001, 0x00015730,
    0x00170001, 0x000158B0,
    0x00170001, 0x00015A30,
    0x00170001, 0x00015BB0,
    0x00170001, 0x00015D30,
    0x00170001, 0x00015EB0,
    0x00170001, 0x00016030,
    0x00170001, 0x000161B0,
    0x00170001, 0x00016330,
    0x00170001, 0x000164B0,
    0x00170001, 0x00016630,
    0x00170001, 0x000167B0,
    0x00170001, 0x00016930,
    0x00170101, 0x00016AA0,
    0x00170101, 0x00016C10,
    0x00170101, 0x00016D80,
    0x00170101, 0x00016EF0,
    0x00170101, 0x00017060,
    0x00170101, 0x000171D0,
    0x00170101, 0x00017340,
    0x00170101, 0x000174B0,
    0x00170101, 0x00017620,
    0x00170101, 0x00017790,
    0x00170101, 0x00017900,
    0x00170101, 0x00017A70,
    0x00160101, 0x00017BE0,
    0x00160101, 0x00017D40,
    0x00160101, 0x00017EA0,
    0x00160101, 0x00018000,
    0x00160101, 0x00018160,
    0x00160101, 0x000182C0,
    0x00160101, 0x00018420,
    0x00160101, 0x00018580,
    0x00160101, 0x000186E0,
    0x00160101, 0x00018840,
    0x00160101, 0x000189A0,
    0x00160101, 0x00018B00,
    0x00160101, 0x00018C60,
    0x00160101, 0x00018DC0,
    0x00160101, 0x00018F20,
    0x00160101, 0x00019080,
    0x00160101, 0x000191E0,
    0x00160201, 0x00019330,
    0x00160201, 0x00019480,
    0x00160201, 0x000195D0,
    0x00160201, 0x00019720,
    0x00160201, 0x00019870,
    0x00160201, 0x000199C0,
    0x00160201, 0x00019B10,
    0x00160201, 0x00019C60,
    0x00160201, 0x00019DB0,
    0x00150201, 0x00019F00,
    0x00150201, 0x0001A040,
    0x00150201, 0x0001A180,
    0x00150201, 0x0001A2C0,
    0x00150201, 0x0001A400,
    0x00150201, 0x0001A540,
    0x00150201, 0x0001A680,
    0x00150201, 0x0001A7C0,
    0x00150201, 0x0001A900,
    0x00150201, 0x0001AA40,
    0x00150201, 0x0001AB80,
    0x00150201, 0x0001ACC0,
    0x00150301, 0x0001ADF0,
    0x00150301, 0x0001AF20,
    0x00150301, 0x0001B050,
    0x00150301, 0x0001B180,
    0x00150301, 0x0001B2B0,
    0x00150301, 0x0001B3E0,
    0x00150301, 0x0001B510,
    0x00140301, 0x0001B640,
    0x00140301, 0x0001B760,
    0x00140301, 0x0001B880,
    0x00140301, 0x0001B9A0,
    0x00140301, 0x0001BAC0,
    0x00140301, 0x0001BBE0,
    0x00140301, 0x0001BD00,
    0x00140301, 0x0001BE20,
    0x00140301, 0x0001BF40,
    0x00140301, 0x0001C060,
    0x00140401, 0x0001C170,
    0x00140401, 0x0001C280,
    0x00140401, 0x0001C390,
    0x00140401, 0x0001C4A0,
    0x00140401, 0x0001C5B0,
    0x00130401, 0x0001C6C0,
    0x00130401, 0x0001C7C0,
    0x00130401, 0x0001C8C0,
    0x00130401, 0x0001C9C0,
    0x00130401, 0x0001CAC0,
    0x00130401, 0x0001CBC0,
    0x00130401, 0x0001CCC0,
    0x00130401, 0x0001CDC0,
    0x00130501, 0x0001CEB0,
    0x00130501, 0x0001CFA0,
    0x00130501, 0x0001D090,
    0x00130501, 0x0001D180,
    0x00120501, 0x0001D270,
    0x00120501, 0x0001D350,
    0x00120501, 0x0001D430,
    0x00120501, 0x0001D510,
    0x00120501, 0x0001D5F0,
    0x00120501, 0x0001D6D0,
    0x00120501, 0x0001D7B0,
    0x00120601, 0x0001D880,
    0x00120601, 0x0001D950,
    0x00120601, 0x0001DA20,
    0x00110601, 0x0001DAF0,
    0x00110601, 0x0001DBB0,
    0x00110601, 0x0001DC70,
    0x00110601, 0x0001DD30,
    0x00110601, 0x0001DDF0,
    0x00110701, 0x0001DEA0,
    0x00110701, 0x0001DF50,
    0x00110701, 0x0001E000,
    0x00100701, 0x0001E0B0,
    0x00100701, 0x0001E150,
    0x00100701, 0x0001E1F0,
    0x00100701, 0x0001E290,
    0x00100801, 0x0001E320,
    0x00100801, 0x0001E3B0,
    0x000F0801, 0x0001E440,
    0x000F0801, 0x0001E4C0,
    0x000F0801, 0x0001E540,
    0x000F0901, 0x0001E5B0,
    0x000F0901, 0x0001E620,
    0x000E0901, 0x0001E690,
    0x000E0901, 0x0001E6F0,
    0x000E0A01, 0x0001E740,
    0x000D0A01, 0x0001E790,
    0x000D0B01, 0x0001E7C0
};
    
#else
  #error "selected color format not supported"
#endif

#ifdef __cplusplus
}
#endif

#endif /* __STM32L4R9I_EVAL_GFXMMU_LUT_H */

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
